package com.AccountName.thumbnailmaker.crop;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.RectF;
import android.media.ExifInterface;
import android.os.Bundle;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageView;
import com.AccountName.thumbnailmaker.R;
import com.AccountName.thumbnailmaker.scale.SubsamplingScaleImageView;


public class CropImageView extends FrameLayout {

    public static final int DEFAULT_ASPECT_RATIO_X = 1;
    public static final int DEFAULT_ASPECT_RATIO_Y = 1;
    public static final boolean DEFAULT_FIXED_ASPECT_RATIO = false;
    public static final int DEFAULT_GUIDELINES = 1;
    private static final int DEFAULT_IMAGE_RESOURCE = 0;
    private static final String DEGREES_ROTATED = "DEGREES_ROTATED";
    private static final Rect EMPTY_RECT = new Rect();
    private int mAspectRatioX = 1;
    private int mAspectRatioY = 1;
    private Bitmap mBitmap;
    private CropOverlayView mCropOverlayView;
    private int mDegreesRotated = 0;
    private boolean mFixAspectRatio = false;
    private int mGuidelines = 1;
    private int mImageResource = 0;
    private ImageView mImageView;
    private int mLayoutHeight;
    private int mLayoutWidth;

    public CropImageView(Context context) {
        super(context);
        init(context);
    }

    public CropImageView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init(context);
    }

    public Parcelable onSaveInstanceState() {
        Bundle bundle = new Bundle();
        bundle.putParcelable("instanceState", super.onSaveInstanceState());
        bundle.putInt(DEGREES_ROTATED, this.mDegreesRotated);
        return bundle;
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (parcelable instanceof Bundle) {
            Bundle bundle = (Bundle) parcelable;
            if (this.mBitmap != null) {
                this.mDegreesRotated = bundle.getInt(DEGREES_ROTATED);
                int i = this.mDegreesRotated;
                rotateImage(this.mDegreesRotated);
                this.mDegreesRotated = i;
            }
            super.onRestoreInstanceState(bundle.getParcelable("instanceState"));
            return;
        }
        super.onRestoreInstanceState(parcelable);
    }


    public void onSizeChanged(int i, int i2, int i3, int i4) {
        if (this.mBitmap != null) {
            this.mCropOverlayView.setBitmapRect(ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this));
            return;
        }
        this.mCropOverlayView.setBitmapRect(EMPTY_RECT);
    }


    public void onMeasure(int i, int i2) {
        int mode = MeasureSpec.getMode(i);
        int size = MeasureSpec.getSize(i);
        int mode2 = MeasureSpec.getMode(i2);
        int size2 = MeasureSpec.getSize(i2);
        if (this.mBitmap != null) {
            super.onMeasure(i, i2);
            if (size2 == 0) {
                size2 = this.mBitmap.getHeight();
            }
            double width = size < this.mBitmap.getWidth() ? ((double) size) / ((double) this.mBitmap.getWidth()) : Double.POSITIVE_INFINITY;
            double height = size2 < this.mBitmap.getHeight() ? ((double) size2) / ((double) this.mBitmap.getHeight()) : Double.POSITIVE_INFINITY;
            if (width == Double.POSITIVE_INFINITY && height == Double.POSITIVE_INFINITY) {
                i = this.mBitmap.getWidth();
                i2 = this.mBitmap.getHeight();
            } else if (width <= height) {
                i2 = (int) (((double) this.mBitmap.getHeight()) * width);
                i = size;
            } else {
                i = (int) (((double) this.mBitmap.getWidth()) * height);
                i2 = size2;
            }
            i = getOnMeasureSpec(mode, size, i);
            i2 = getOnMeasureSpec(mode2, size2, i2);
            this.mLayoutWidth = i;
            this.mLayoutHeight = i2;
            this.mCropOverlayView.setBitmapRect(ImageViewUtil.getBitmapRectCenterInside(this.mBitmap.getWidth(), this.mBitmap.getHeight(), this.mLayoutWidth, this.mLayoutHeight));
            setMeasuredDimension(this.mLayoutWidth, this.mLayoutHeight);
            return;
        }
        this.mCropOverlayView.setBitmapRect(EMPTY_RECT);
        setMeasuredDimension(size, size2);
    }


    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        if (this.mLayoutWidth > 0 && this.mLayoutHeight > 0) {
            ViewGroup.LayoutParams layoutParams = getLayoutParams();
            layoutParams.width = this.mLayoutWidth;
            layoutParams.height = this.mLayoutHeight;
            setLayoutParams(layoutParams);
        }
    }

    public int getImageResource() {
        return this.mImageResource;
    }

    public void setImageBitmap(Bitmap bitmap) {
        this.mBitmap = bitmap;
        this.mImageView.setImageBitmap(this.mBitmap);
        if (this.mCropOverlayView != null) {
            this.mCropOverlayView.resetCropOverlayView();
        }
    }

    public void setImageBitmap(Bitmap bitmap, ExifInterface exifInterface) {
        if (bitmap != null) {
            if (exifInterface == null) {
                setImageBitmap(bitmap);
                return;
            }
            Matrix matrix = new Matrix();
            int attributeInt = exifInterface.getAttributeInt("Orientation", 1);
            attributeInt = attributeInt != 3 ? attributeInt != 6 ? attributeInt != 8 ? -1 : SubsamplingScaleImageView.ORIENTATION_270 : 90 : SubsamplingScaleImageView.ORIENTATION_180;
            if (attributeInt == -1) {
                setImageBitmap(bitmap);
            } else {
                matrix.postRotate((float) attributeInt);
                setImageBitmap(Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true));
                bitmap.recycle();
            }
        }
    }

    public void setImageResource(int i) {
        if (i != 0) {
            setImageBitmap(BitmapFactory.decodeResource(getResources(), i));
        }
    }

    public Bitmap getCroppedImage() {
        Rect bitmapRectCenterInside = ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this.mImageView);
        float width = ((float) this.mBitmap.getWidth()) / ((float) bitmapRectCenterInside.width());
        float height = ((float) this.mBitmap.getHeight()) / ((float) bitmapRectCenterInside.height());
        float coordinate = Edge.LEFT.getCoordinate() - ((float) bitmapRectCenterInside.left);
        float coordinate2 = Edge.TOP.getCoordinate() - ((float) bitmapRectCenterInside.top);
        return Bitmap.createBitmap(this.mBitmap, (int) (coordinate * width), (int) (coordinate2 * height), (int) (Edge.getWidth() * width), (int) (Edge.getHeight() * height));
    }

    public float getActualCropX() {
        Rect bitmapRectCenterInside = ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this.mImageView);
        float width = ((float) this.mBitmap.getWidth()) / ((float) bitmapRectCenterInside.width());
        this.mBitmap.getHeight();
        bitmapRectCenterInside.height();
        float coordinate = Edge.LEFT.getCoordinate() - ((float) bitmapRectCenterInside.left);
        Edge.TOP.getCoordinate();
        int i = bitmapRectCenterInside.top;
        Edge.getWidth();
        Edge.getHeight();
        return coordinate * width;
    }

    public float getActualCropY() {
        Rect bitmapRectCenterInside = ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this.mImageView);
        this.mBitmap.getWidth();
        bitmapRectCenterInside.width();
        float height = ((float) this.mBitmap.getHeight()) / ((float) bitmapRectCenterInside.height());
        Edge.LEFT.getCoordinate();
        int i = bitmapRectCenterInside.left;
        float coordinate = Edge.TOP.getCoordinate() - ((float) bitmapRectCenterInside.top);
        Edge.getWidth();
        Edge.getHeight();
        return coordinate * height;
    }

    public float getActualCropWidth() {
        Rect bitmapRectCenterInside = ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this.mImageView);
        float width = ((float) this.mBitmap.getWidth()) / ((float) bitmapRectCenterInside.width());
        this.mBitmap.getHeight();
        bitmapRectCenterInside.height();
        Edge.LEFT.getCoordinate();
        int i = bitmapRectCenterInside.left;
        Edge.TOP.getCoordinate();
        int i2 = bitmapRectCenterInside.top;
        float width2 = Edge.getWidth();
        Edge.getHeight();
        return width2 * width;
    }

    public float getActualCropHeight() {
        Rect bitmapRectCenterInside = ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this.mImageView);
        this.mBitmap.getWidth();
        bitmapRectCenterInside.width();
        float height = ((float) this.mBitmap.getHeight()) / ((float) bitmapRectCenterInside.height());
        Edge.LEFT.getCoordinate();
        int i = bitmapRectCenterInside.left;
        Edge.TOP.getCoordinate();
        int i2 = bitmapRectCenterInside.top;
        Edge.getWidth();
        return Edge.getHeight() * height;
    }

    public RectF getActualCropRect() {
        Rect bitmapRectCenterInside = ImageViewUtil.getBitmapRectCenterInside(this.mBitmap, this.mImageView);
        float width = ((float) this.mBitmap.getWidth()) / ((float) bitmapRectCenterInside.width());
        float height = ((float) this.mBitmap.getHeight()) / ((float) bitmapRectCenterInside.height());
        float coordinate = Edge.LEFT.getCoordinate() - ((float) bitmapRectCenterInside.left);
        float coordinate2 = Edge.TOP.getCoordinate() - ((float) bitmapRectCenterInside.top);
        coordinate *= width;
        coordinate2 *= height;
        return new RectF(Math.max(0.0f, coordinate), Math.max(0.0f, coordinate2), Math.min((float) this.mBitmap.getWidth(), (Edge.getWidth() * width) + coordinate), Math.min((float) this.mBitmap.getHeight(), (Edge.getHeight() * height) + coordinate2));
    }

    public void setFixedAspectRatio(boolean z) {
        this.mCropOverlayView.setFixedAspectRatio(z);
    }

    public void setGuidelines(int i) {
        this.mCropOverlayView.setGuidelines(i);
    }

    public void enableCropOverlayView(boolean z) {
        this.mCropOverlayView.setCropOverlayEnabled(z);
    }

    public void setAspectRatio(int i, int i2) {
        this.mAspectRatioX = i;
        this.mCropOverlayView.setAspectRatioX(this.mAspectRatioX);
        this.mAspectRatioY = i2;
        this.mCropOverlayView.setAspectRatioY(this.mAspectRatioY);
    }

    public void rotateImage(int i) {
        Matrix matrix = new Matrix();
        matrix.postRotate((float) i);
        this.mBitmap = Bitmap.createBitmap(this.mBitmap, 0, 0, this.mBitmap.getWidth(), this.mBitmap.getHeight(), matrix, true);
        setImageBitmap(this.mBitmap);
        this.mDegreesRotated += i;
        this.mDegreesRotated %= 360;
    }

    private void init(Context context) {
        View inflate = LayoutInflater.from(context).inflate(R.layout.crop_image_view, this, true);
        this.mImageView = (ImageView) inflate.findViewById(R.id.ImageView_image);
        setImageResource(this.mImageResource);
        this.mCropOverlayView = (CropOverlayView) inflate.findViewById(R.id.CropOverlayView);
        this.mCropOverlayView.setInitialAttributeValues(this.mGuidelines, this.mFixAspectRatio, this.mAspectRatioX, this.mAspectRatioY);
    }

    private static int getOnMeasureSpec(int i, int i2, int i3) {
        if (i == 1073741824) {
            return i2;
        }
        return i == Integer.MIN_VALUE ? Math.min(i3, i2) : i3;
    }
}
