package com.AccountName.thumbnailmaker.main;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.os.Build;
import android.util.Log;

import com.msl.demo.view.ComponentInfo;
import com.msl.textmodule.TextInfo;

import java.util.ArrayList;

public class DatabaseHandler extends SQLiteOpenHelper {

    private static final String BG_ALPHA = "BG_ALPHA";
    private static final String BG_COLOR = "BG_COLOR";
    private static final String BG_DRAWABLE = "BG_DRAWABLE";
    private static final String CIV_HEIGHT = "CIV_HEIGHT";
    private static final String CIV_WIDTH = "CIV_WIDTH";
    private static final String COLORTYPE = "COLORTYPE";
    private static final String COMPONENT_INFO = "COMPONENT_INFO";
    private static final String COMP_ID = "COMP_ID";
    private static final String CREATE_TABLE_COMPONENT_INFO = "CREATE TABLE COMPONENT_INFO(COMP_ID INTEGER PRIMARY KEY,TEMPLATE_ID TEXT,POS_X TEXT,POS_Y TEXT,WIDHT TEXT,HEIGHT TEXT,ROTATION TEXT,Y_ROTATION TEXT,RES_ID TEXT,TYPE TEXT,ORDER_ TEXT,STC_COLOR TEXT,STC_OPACITY TEXT,XROTATEPROG TEXT,YROTATEPROG TEXT,ZROTATEPROG TEXT,STC_SCALE TEXT,STKR_PATH TEXT,COLORTYPE TEXT,STC_HUE TEXT,FIELD_ONE TEXT,FIELD_TWO TEXT,FIELD_THREE TEXT,FIELD_FOUR TEXT)";
    private static final String CREATE_TABLE_TEMPLATES = "CREATE TABLE TEMPLATES(TEMPLATE_ID INTEGER PRIMARY KEY,THUMB_URI TEXT,FRAME_NAME TEXT,RATIO TEXT,PROFILE_TYPE TEXT,SEEK_VALUE TEXT,TYPE TEXT,TEMP_PATH TEXT,TEMP_COLOR TEXT,OVERLAY_NAME TEXT,OVERLAY_OPACITY TEXT,OVERLAY_BLUR TEXT,SHAP_NAME TEXT,CUSTOM_WI TEXT,CUSTOM_HE TEXT,CUSTOM_X TEXT,CUSTOM_Y TEXT,CIV_WIDTH TEXT,CIV_HEIGHT TEXT,SAVEIMAGE_WIDTH TEXT,SAVEIMAGE_HEIGHT TEXT)";
    private static final String CREATE_TABLE_TEXT_INFO = "CREATE TABLE TEXT_INFO(TEXT_ID INTEGER PRIMARY KEY,TEMPLATE_ID TEXT,TEXT TEXT,FONT_NAME TEXT,TEXT_COLOR TEXT,TEXT_ALPHA TEXT,SHADOW_COLOR TEXT,SHADOW_PROG TEXT,BG_DRAWABLE TEXT,BG_COLOR TEXT,BG_ALPHA TEXT,POS_X TEXT,POS_Y TEXT,WIDHT TEXT,HEIGHT TEXT,ROTATION TEXT,TYPE TEXT,ORDER_ TEXT,XROTATEPROG TEXT,YROTATEPROG TEXT,ZROTATEPROG TEXT,CURVEPROG TEXT,FIELD_ONE TEXT,FIELD_TWO TEXT,FIELD_THREE TEXT,FIELD_FOUR TEXT)";
    private static final String CURVEPROG = "CURVEPROG";
    private static final String CUSTOM_HE = "CUSTOM_HE";
    private static final String CUSTOM_WI = "CUSTOM_WI";
    private static final String CUSTOM_X = "CUSTOM_X";
    private static final String CUSTOM_Y = "CUSTOM_Y";
    private static final String DATABASE_NAME = "THUMBNAILMAKER_DB";
    private static final int DATABASE_VERSION = 1;
    private static final String FIELD_FOUR = "FIELD_FOUR";
    private static final String FIELD_ONE = "FIELD_ONE";
    private static final String FIELD_THREE = "FIELD_THREE";
    private static final String FIELD_TWO = "FIELD_TWO";
    private static final String FONT_NAME = "FONT_NAME";
    private static final String FRAME_NAME = "FRAME_NAME";
    private static final String HEIGHT = "HEIGHT";
    private static final String ORDER = "ORDER_";
    private static final String OVERLAY_BLUR = "OVERLAY_BLUR";
    private static final String OVERLAY_NAME = "OVERLAY_NAME";
    private static final String OVERLAY_OPACITY = "OVERLAY_OPACITY";
    private static final String POS_X = "POS_X";
    private static final String POS_Y = "POS_Y";
    private static final String PROFILE_TYPE = "PROFILE_TYPE";
    private static final String RATIO = "RATIO";
    private static final String RES_ID = "RES_ID";
    private static final String ROTATION = "ROTATION";
    private static final String SAVEIMAGE_HEIGHT = "SAVEIMAGE_HEIGHT";
    private static final String SAVEIMAGE_WIDTH = "SAVEIMAGE_WIDTH";
    private static final String SEEK_VALUE = "SEEK_VALUE";
    private static final String SHADOW_COLOR = "SHADOW_COLOR";
    private static final String SHADOW_PROG = "SHADOW_PROG";
    private static final String SHAP_NAME = "SHAP_NAME";
    private static final String STC_COLOR = "STC_COLOR";
    private static final String STC_HUE = "STC_HUE";
    private static final String STC_OPACITY = "STC_OPACITY";
    private static final String STC_SCALE = "STC_SCALE";
    private static final String STKR_PATH = "STKR_PATH";
    private static final String TEMPLATES = "TEMPLATES";
    private static final String TEMPLATE_ID = "TEMPLATE_ID";
    private static final String TEMP_COLOR = "TEMP_COLOR";
    private static final String TEMP_PATH = "TEMP_PATH";
    private static final String TEXT = "TEXT";
    private static final String TEXT_ALPHA = "TEXT_ALPHA";
    private static final String TEXT_COLOR = "TEXT_COLOR";
    private static final String TEXT_ID = "TEXT_ID";
    private static final String TEXT_INFO = "TEXT_INFO";
    private static final String THUMB_URI = "THUMB_URI";
    private static final String TYPE = "TYPE";
    private static final String WIDHT = "WIDHT";
    private static final String XROTATEPROG = "XROTATEPROG";
    private static final String YROTATEPROG = "YROTATEPROG";
    private static final String Y_ROTATION = "Y_ROTATION";
    private static final String ZROTATEPROG = "ZROTATEPROG";

    public void onUpgrade(SQLiteDatabase sQLiteDatabase, int i, int i2) {
    }

    public DatabaseHandler(Context context) {
        super(context, DATABASE_NAME, null, 1);
    }

    public static DatabaseHandler getDbHandler(Context context) {
        return new DatabaseHandler(context);
    }

    @Override
    public void onCreate(SQLiteDatabase sQLiteDatabase) {
        sQLiteDatabase.execSQL(CREATE_TABLE_TEMPLATES);
        sQLiteDatabase.execSQL(CREATE_TABLE_TEXT_INFO);
        sQLiteDatabase.execSQL(CREATE_TABLE_COMPONENT_INFO);
        Log.e("testing", "Database Created");
    }

    @Override
    public void onOpen(SQLiteDatabase database) {
        super.onOpen(database);
        if (Build.VERSION.SDK_INT >= 28) {
            database.disableWriteAheadLogging();
        }
    }


    public long insertTemplateRow(TemplateInfo templateInfo) {

        SQLiteDatabase writableDatabase = getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(THUMB_URI, templateInfo.getTHUMB_URI());
        contentValues.put(FRAME_NAME, templateInfo.getFRAME_NAME());
        contentValues.put(RATIO, templateInfo.getRATIO());
        contentValues.put(PROFILE_TYPE, templateInfo.getPROFILE_TYPE());
        contentValues.put(SEEK_VALUE, templateInfo.getSEEK_VALUE());
        contentValues.put(TYPE, templateInfo.getTYPE());
        contentValues.put(TEMP_PATH, templateInfo.getTEMP_PATH());
        contentValues.put(TEMP_COLOR, templateInfo.getTEMPCOLOR());
        contentValues.put(OVERLAY_NAME, templateInfo.getOVERLAY_NAME());
        contentValues.put(OVERLAY_OPACITY, Integer.valueOf(templateInfo.getOVERLAY_OPACITY()));
        contentValues.put(OVERLAY_BLUR, Integer.valueOf(templateInfo.getOVERLAY_BLUR()));
        contentValues.put(SHAP_NAME, templateInfo.getSHAP_NAME());
        contentValues.put(CUSTOM_WI, Float.valueOf(templateInfo.getCustom_Wi()));
        contentValues.put(CUSTOM_HE, Float.valueOf(templateInfo.getCustom_He()));
        contentValues.put(CUSTOM_X, Float.valueOf(templateInfo.getCustom_X()));
        contentValues.put(CUSTOM_Y, Float.valueOf(templateInfo.getCustom_Y()));
        contentValues.put(CIV_WIDTH, Float.valueOf(templateInfo.getCiv_width()));
        contentValues.put(CIV_HEIGHT, Float.valueOf(templateInfo.getCiv_height()));
        contentValues.put(SAVEIMAGE_WIDTH, Integer.valueOf(templateInfo.getSaveImageWidth()));
        contentValues.put(SAVEIMAGE_HEIGHT, Integer.valueOf(templateInfo.getSaveImageHeight()));
        Log.e("testing", "Before insertion ");
        long insert = writableDatabase.insert(TEMPLATES, null, contentValues);
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("ID ");
        stringBuilder.append(insert);
        Log.e("testing", stringBuilder.toString());
        stringBuilder = new StringBuilder();
        stringBuilder.append("Framepath ");
        stringBuilder.append(templateInfo.getFRAME_NAME());
        Log.e("testing", stringBuilder.toString());
        stringBuilder = new StringBuilder();
        stringBuilder.append("Thumb Path ");
        stringBuilder.append(templateInfo.getTHUMB_URI());
        Log.e("testing", stringBuilder.toString());
        writableDatabase.close();
        Log.e("insert", ""+insert);
        return insert;
    }

    public void insertComponentInfoRow(ComponentInfo componentInfo) {

        SQLiteDatabase writableDatabase = getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(TEMPLATE_ID, Integer.valueOf(componentInfo.getTEMPLATE_ID()));
        contentValues.put(POS_X, Float.valueOf(componentInfo.getPOS_X()));
        contentValues.put(POS_Y, Float.valueOf(componentInfo.getPOS_Y()));
        contentValues.put(WIDHT, Integer.valueOf(componentInfo.getWIDTH()));
        contentValues.put(HEIGHT, Integer.valueOf(componentInfo.getHEIGHT()));
        contentValues.put(ROTATION, Float.valueOf(componentInfo.getROTATION()));
        contentValues.put(Y_ROTATION, Float.valueOf(componentInfo.getY_ROTATION()));
        contentValues.put(RES_ID, componentInfo.getRES_ID());
        contentValues.put(TYPE, componentInfo.getTYPE());
        contentValues.put(ORDER, Integer.valueOf(componentInfo.getORDER()));
        contentValues.put(STC_COLOR, Integer.valueOf(componentInfo.getSTC_COLOR()));
        contentValues.put(STC_OPACITY, Integer.valueOf(componentInfo.getSTC_OPACITY()));
        contentValues.put(XROTATEPROG, Integer.valueOf(componentInfo.getXRotateProg()));
        contentValues.put(YROTATEPROG, Integer.valueOf(componentInfo.getYRotateProg()));
        contentValues.put(ZROTATEPROG, Integer.valueOf(componentInfo.getZRotateProg()));
        contentValues.put(STC_SCALE, Integer.valueOf(componentInfo.getScaleProg()));
        contentValues.put(STKR_PATH, componentInfo.getSTKR_PATH());
        contentValues.put(COLORTYPE, componentInfo.getCOLORTYPE());
        contentValues.put(STC_HUE, Integer.valueOf(componentInfo.getSTC_HUE()));
        contentValues.put(FIELD_ONE, Integer.valueOf(componentInfo.getFIELD_ONE()));
        contentValues.put(FIELD_TWO, componentInfo.getFIELD_TWO());
        contentValues.put(FIELD_THREE, componentInfo.getFIELD_THREE());
        contentValues.put(FIELD_FOUR, componentInfo.getFIELD_FOUR());
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("");
        stringBuilder.append(componentInfo.getPOS_X());
        stringBuilder.append(" ,");
        stringBuilder.append(componentInfo.getPOS_Y());
        stringBuilder.append(" ,");
        stringBuilder.append(componentInfo.getWIDTH());
        stringBuilder.append(" ,");
        stringBuilder.append(componentInfo.getHEIGHT());
        stringBuilder.append(" ,");
        stringBuilder.append(componentInfo.getROTATION());
        stringBuilder.append(" ,");
        stringBuilder.append(componentInfo.getY_ROTATION());
        stringBuilder.append(" ,");
        stringBuilder.append(componentInfo.getRES_ID());
        Log.e("insert sticker", stringBuilder.toString());
        writableDatabase.insert(COMPONENT_INFO, null, contentValues);
        writableDatabase.close();

    }

    public void insertTextRow(TextInfo textInfo) {

        Log.e("insertTextRow", "insertTextRow");
        SQLiteDatabase writableDatabase = getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(TEMPLATE_ID, Integer.valueOf(textInfo.getTEMPLATE_ID()));
        contentValues.put(TEXT, textInfo.getTEXT());
        contentValues.put(FONT_NAME, textInfo.getFONT_NAME());
        contentValues.put(TEXT_COLOR, Integer.valueOf(textInfo.getTEXT_COLOR()));
        contentValues.put(TEXT_ALPHA, Integer.valueOf(textInfo.getTEXT_ALPHA()));
        contentValues.put(SHADOW_COLOR, Integer.valueOf(textInfo.getSHADOW_COLOR()));
        contentValues.put(SHADOW_PROG, Integer.valueOf(textInfo.getSHADOW_PROG()));
        contentValues.put(BG_DRAWABLE, textInfo.getBG_DRAWABLE());
        contentValues.put(BG_COLOR, Integer.valueOf(textInfo.getBG_COLOR()));
        contentValues.put(BG_ALPHA, Integer.valueOf(textInfo.getBG_ALPHA()));
        contentValues.put(POS_X, Float.valueOf(textInfo.getPOS_X()));
        contentValues.put(POS_Y, Float.valueOf(textInfo.getPOS_Y()));
        contentValues.put(WIDHT, Integer.valueOf(textInfo.getWIDTH()));
        contentValues.put(HEIGHT, Integer.valueOf(textInfo.getHEIGHT()));
        contentValues.put(ROTATION, Float.valueOf(textInfo.getROTATION()));
        contentValues.put(TYPE, textInfo.getTYPE());
        contentValues.put(ORDER, Integer.valueOf(textInfo.getORDER()));
        contentValues.put(XROTATEPROG, Integer.valueOf(textInfo.getXRotateProg()));
        contentValues.put(YROTATEPROG, Integer.valueOf(textInfo.getYRotateProg()));
        contentValues.put(ZROTATEPROG, Integer.valueOf(textInfo.getZRotateProg()));
        contentValues.put(CURVEPROG, Integer.valueOf(textInfo.getCurveRotateProg()));
        contentValues.put(FIELD_ONE, Integer.valueOf(textInfo.getFIELD_ONE()));
        contentValues.put(FIELD_TWO, textInfo.getFIELD_TWO());
        contentValues.put(FIELD_THREE, textInfo.getFIELD_THREE());
        contentValues.put(FIELD_FOUR, textInfo.getFIELD_FOUR());
        Log.e("testing", "Before TEXT insertion ");
        long insert = writableDatabase.insert(TEXT_INFO, null, contentValues);
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("TEXT ID ");
        stringBuilder.append(insert);
        Log.e("testing", stringBuilder.toString());
        writableDatabase.close();
    }


    public TemplateInfo getTemplateByID(int i) {

        Log.e("getTemplateByID", "" + i);

        TemplateInfo templateInfo = new TemplateInfo();
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("SELECT  * FROM TEMPLATES WHERE TEMPLATE_ID = ");
        stringBuilder.append(i);
        stringBuilder.append(";");
        String stringBuilder2 = stringBuilder.toString();
        SQLiteDatabase readableDatabase = getWritableDatabase();
        Cursor rawQuery = readableDatabase.rawQuery(stringBuilder2, null);

//
//        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
//            if (rawQuery != null) {
//                rawQuery.close();
//            }
//            readableDatabase.close();
//
//            Log.e("getTemplateByID", "null");
//            return templateInfo;
//        }

        // Log.e("rawQuery", "  Count=== " + rawQuery.getCount());

        if (rawQuery != null && rawQuery.moveToFirst()) {

            Log.e("getTemplateByID", "not null");

            do {
                Log.e("setPROFILE_TYPE", "" + rawQuery.getString(4));
                templateInfo.setTEMPLATE_ID(rawQuery.getInt(0));
                templateInfo.setTHUMB_URI(rawQuery.getString(1));
                templateInfo.setFRAME_NAME(rawQuery.getString(2));
                templateInfo.setRATIO(rawQuery.getString(3));
                templateInfo.setPROFILE_TYPE(rawQuery.getString(4));
                templateInfo.setSEEK_VALUE(rawQuery.getString(5));
                templateInfo.setTYPE(rawQuery.getString(6));
                templateInfo.setTEMP_PATH(rawQuery.getString(7));
                templateInfo.setTEMPCOLOR(rawQuery.getString(8));
                templateInfo.setOVERLAY_NAME(rawQuery.getString(9));
                templateInfo.setOVERLAY_OPACITY(rawQuery.getInt(10));
                templateInfo.setOVERLAY_BLUR(rawQuery.getInt(11));
                templateInfo.setSHAP_NAME(rawQuery.getString(12));
                templateInfo.setCustom_Wi((float) rawQuery.getInt(13));
                templateInfo.setCustom_He((float) rawQuery.getInt(14));
                templateInfo.setCustom_X((float) rawQuery.getInt(15));
                templateInfo.setCustom_Y((float) rawQuery.getInt(16));
                templateInfo.setCiv_width((float) rawQuery.getInt(17));
                templateInfo.setCiv_height((float) rawQuery.getInt(18));
                templateInfo.setSaveImageWidth(rawQuery.getInt(19));
                templateInfo.setSaveImageHeight(rawQuery.getInt(20));
            } while (rawQuery.moveToNext());

            rawQuery.close();
        }
        readableDatabase.close();
        return templateInfo;
    }

    public ArrayList<TemplateInfo> getTemplateList(String str) {
        ArrayList arrayList = new ArrayList();
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("SELECT  * FROM TEMPLATES WHERE TYPE='");
        stringBuilder.append(str);
        stringBuilder.append("' ORDER BY ");
        stringBuilder.append(TEMPLATE_ID);
        stringBuilder.append(" DESC;");
        str = stringBuilder.toString();
        SQLiteDatabase readableDatabase = getReadableDatabase();
        Cursor rawQuery = readableDatabase.rawQuery(str, null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            readableDatabase.close();
            return arrayList;
        }
        do {
            TemplateInfo templateInfo = new TemplateInfo();
            templateInfo.setTEMPLATE_ID(rawQuery.getInt(0));
            templateInfo.setTHUMB_URI(rawQuery.getString(1));
            templateInfo.setFRAME_NAME(rawQuery.getString(2));
            templateInfo.setRATIO(rawQuery.getString(3));
            templateInfo.setPROFILE_TYPE(rawQuery.getString(4));
            templateInfo.setSEEK_VALUE(rawQuery.getString(5));
            templateInfo.setTYPE(rawQuery.getString(6));
            templateInfo.setTEMP_PATH(rawQuery.getString(7));
            templateInfo.setTEMPCOLOR(rawQuery.getString(8));
            templateInfo.setOVERLAY_NAME(rawQuery.getString(9));
            templateInfo.setOVERLAY_OPACITY(rawQuery.getInt(10));
            templateInfo.setOVERLAY_BLUR(rawQuery.getInt(11));
            templateInfo.setSHAP_NAME(rawQuery.getString(12));
            templateInfo.setCustom_Wi(rawQuery.getFloat(13));
            templateInfo.setCustom_He(rawQuery.getFloat(14));
            templateInfo.setCustom_X(rawQuery.getFloat(15));
            templateInfo.setCustom_Y(rawQuery.getFloat(16));
            templateInfo.setCiv_width(rawQuery.getFloat(17));
            templateInfo.setCiv_height(rawQuery.getFloat(18));
            templateInfo.setSaveImageWidth(rawQuery.getInt(19));
            templateInfo.setSaveImageHeight(rawQuery.getInt(20));
            arrayList.add(templateInfo);
        } while (rawQuery.moveToNext());
        readableDatabase.close();
        return arrayList;
    }

    public ArrayList<TemplateInfo> getTemplateListDes(String str) {
        ArrayList arrayList = new ArrayList();
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("SELECT  * FROM TEMPLATES WHERE TYPE='");
        stringBuilder.append(str);
        stringBuilder.append("' ORDER BY ");
        stringBuilder.append(TEMPLATE_ID);
        stringBuilder.append(" DESC;");
        str = stringBuilder.toString();
        SQLiteDatabase readableDatabase = getReadableDatabase();
        Cursor rawQuery = readableDatabase.rawQuery(str, null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            readableDatabase.close();
            stringBuilder = new StringBuilder();
            stringBuilder.append("");
            stringBuilder.append(arrayList.size());
            Log.e("templateList size is", stringBuilder.toString());
            return arrayList;
        }
        do {
            TemplateInfo templateInfo = new TemplateInfo();
            templateInfo.setTEMPLATE_ID(rawQuery.getInt(0));
            templateInfo.setTHUMB_URI(rawQuery.getString(1));
            templateInfo.setFRAME_NAME(rawQuery.getString(2));
            templateInfo.setRATIO(rawQuery.getString(3));
            templateInfo.setPROFILE_TYPE(rawQuery.getString(4));
            templateInfo.setSEEK_VALUE(rawQuery.getString(5));
            templateInfo.setTYPE(rawQuery.getString(6));
            templateInfo.setTEMP_PATH(rawQuery.getString(7));
            templateInfo.setTEMPCOLOR(rawQuery.getString(8));
            templateInfo.setOVERLAY_NAME(rawQuery.getString(9));
            templateInfo.setOVERLAY_OPACITY(rawQuery.getInt(10));
            templateInfo.setOVERLAY_BLUR(rawQuery.getInt(11));
            templateInfo.setSHAP_NAME(rawQuery.getString(12));
            templateInfo.setCustom_Wi(rawQuery.getFloat(13));
            templateInfo.setCustom_He(rawQuery.getFloat(14));
            templateInfo.setCustom_X(rawQuery.getFloat(15));
            templateInfo.setCustom_Y(rawQuery.getFloat(16));
            templateInfo.setCiv_width(rawQuery.getFloat(17));
            templateInfo.setCiv_height(rawQuery.getFloat(18));
            templateInfo.setSaveImageWidth(rawQuery.getInt(19));
            templateInfo.setSaveImageHeight(rawQuery.getInt(20));
            arrayList.add(templateInfo);
        } while (rawQuery.moveToNext());
        readableDatabase.close();
        stringBuilder = new StringBuilder();
        stringBuilder.append("");
        stringBuilder.append(arrayList.size());
        Log.e("templateList size is", stringBuilder.toString());
        return arrayList;
    }

    public ArrayList<TemplateInfo> getTemplateList() {
        ArrayList arrayList = new ArrayList();
        SQLiteDatabase readableDatabase = getReadableDatabase();
        Cursor rawQuery = readableDatabase.rawQuery("SELECT  * FROM TEMPLATES ORDER BY TEMPLATE_ID DESC;", null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            readableDatabase.close();
            return arrayList;
        }
        do {
            TemplateInfo templateInfo = new TemplateInfo();
            templateInfo.setTEMPLATE_ID(rawQuery.getInt(0));
            templateInfo.setTHUMB_URI(rawQuery.getString(1));
            templateInfo.setFRAME_NAME(rawQuery.getString(2));
            templateInfo.setRATIO(rawQuery.getString(3));
            templateInfo.setPROFILE_TYPE(rawQuery.getString(4));
            templateInfo.setSEEK_VALUE(rawQuery.getString(5));
            templateInfo.setTYPE(rawQuery.getString(6));
            templateInfo.setTEMP_PATH(rawQuery.getString(7));
            templateInfo.setTEMPCOLOR(rawQuery.getString(8));
            templateInfo.setOVERLAY_NAME(rawQuery.getString(9));
            templateInfo.setOVERLAY_OPACITY(rawQuery.getInt(10));
            templateInfo.setOVERLAY_BLUR(rawQuery.getInt(11));
            templateInfo.setSHAP_NAME(rawQuery.getString(12));
            templateInfo.setCustom_Wi(rawQuery.getFloat(13));
            templateInfo.setCustom_He(rawQuery.getFloat(14));
            templateInfo.setCustom_X(rawQuery.getFloat(15));
            templateInfo.setCustom_Y(rawQuery.getFloat(16));
            templateInfo.setCiv_width(rawQuery.getFloat(17));
            templateInfo.setCiv_height(rawQuery.getFloat(18));
            templateInfo.setSaveImageWidth(rawQuery.getInt(19));
            templateInfo.setSaveImageHeight(rawQuery.getInt(20));
            arrayList.add(templateInfo);
        } while (rawQuery.moveToNext());
        readableDatabase.close();
        return arrayList;
    }

    public ArrayList<ComponentInfo> getComponentInfoList(int i, String str) {
        ArrayList arrayList = new ArrayList();
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("SELECT * FROM COMPONENT_INFO WHERE TEMPLATE_ID='");
        stringBuilder.append(i);
        stringBuilder.append("' AND ");
        stringBuilder.append(TYPE);
        stringBuilder.append(" = '");
        stringBuilder.append(str);
        stringBuilder.append("'");
        String stringBuilder2 = stringBuilder.toString();
        SQLiteDatabase readableDatabase = getReadableDatabase();
        Cursor rawQuery = readableDatabase.rawQuery(stringBuilder2, null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            readableDatabase.close();
            return arrayList;
        }
        do {
            ComponentInfo componentInfo = new ComponentInfo();
            componentInfo.setCOMP_ID(rawQuery.getInt(0));
            componentInfo.setTEMPLATE_ID(rawQuery.getInt(1));
            componentInfo.setPOS_X(rawQuery.getFloat(2));
            componentInfo.setPOS_Y(rawQuery.getFloat(3));
            componentInfo.setWIDTH(rawQuery.getInt(4));
            componentInfo.setHEIGHT(rawQuery.getInt(5));
            componentInfo.setROTATION(rawQuery.getFloat(6));
            componentInfo.setY_ROTATION(rawQuery.getFloat(7));
            componentInfo.setRES_ID(rawQuery.getString(8));
            componentInfo.setTYPE(rawQuery.getString(9));
            componentInfo.setORDER(rawQuery.getInt(10));
            componentInfo.setSTC_COLOR(rawQuery.getInt(11));
            componentInfo.setSTC_OPACITY(rawQuery.getInt(12));
            componentInfo.setXRotateProg(rawQuery.getInt(13));
            componentInfo.setYRotateProg(rawQuery.getInt(14));
            componentInfo.setZRotateProg(rawQuery.getInt(15));
            componentInfo.setScaleProg(rawQuery.getInt(16));
            componentInfo.setSTKR_PATH(rawQuery.getString(17));
            componentInfo.setCOLORTYPE(rawQuery.getString(18));
            componentInfo.setSTC_HUE(rawQuery.getInt(19));
            componentInfo.setFIELD_ONE(rawQuery.getInt(20));
            componentInfo.setFIELD_TWO(rawQuery.getString(21));
            componentInfo.setFIELD_THREE(rawQuery.getString(22));
            componentInfo.setFIELD_FOUR(rawQuery.getString(23));
            arrayList.add(componentInfo);
        } while (rawQuery.moveToNext());
        readableDatabase.close();
        return arrayList;
    }

    public ArrayList<TextInfo> getTextInfoList(int i) {
        ArrayList arrayList = new ArrayList();
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append("SELECT * FROM TEXT_INFO WHERE TEMPLATE_ID='");
        stringBuilder.append(i);
        stringBuilder.append("'");
        String stringBuilder2 = stringBuilder.toString();
        SQLiteDatabase readableDatabase = getReadableDatabase();
        Cursor rawQuery = readableDatabase.rawQuery(stringBuilder2, null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            readableDatabase.close();
            return arrayList;
        }
        do {
            TextInfo textInfo = new TextInfo();
            textInfo.setTEXT_ID(rawQuery.getInt(0));
            textInfo.setTEMPLATE_ID(rawQuery.getInt(1));
            textInfo.setTEXT(rawQuery.getString(2));
            textInfo.setFONT_NAME(rawQuery.getString(3));
            textInfo.setTEXT_COLOR(rawQuery.getInt(4));
            textInfo.setTEXT_ALPHA(rawQuery.getInt(5));
            textInfo.setSHADOW_COLOR(rawQuery.getInt(6));
            textInfo.setSHADOW_PROG(rawQuery.getInt(7));
            textInfo.setBG_DRAWABLE(rawQuery.getString(8));
            textInfo.setBG_COLOR(rawQuery.getInt(9));
            textInfo.setBG_ALPHA(rawQuery.getInt(10));
            textInfo.setPOS_X(rawQuery.getFloat(11));
            textInfo.setPOS_Y(rawQuery.getFloat(12));
            textInfo.setWIDTH(rawQuery.getInt(13));
            textInfo.setHEIGHT(rawQuery.getInt(14));
            textInfo.setROTATION(rawQuery.getFloat(15));
            textInfo.setTYPE(rawQuery.getString(16));
            textInfo.setORDER(rawQuery.getInt(17));
            textInfo.setXRotateProg(rawQuery.getInt(18));
            textInfo.setYRotateProg(rawQuery.getInt(19));
            textInfo.setZRotateProg(rawQuery.getInt(20));
            textInfo.setCurveRotateProg(rawQuery.getInt(21));
            textInfo.setFIELD_ONE(rawQuery.getInt(22));
            textInfo.setFIELD_TWO(rawQuery.getString(23));
            textInfo.setFIELD_THREE(rawQuery.getString(24));
            textInfo.setFIELD_FOUR(rawQuery.getString(25));
            arrayList.add(textInfo);
        } while (rawQuery.moveToNext());
        readableDatabase.close();
        return arrayList;
    }

    public boolean updateSTC_HUE_Value(SQLiteDatabase sQLiteDatabase) {
        sQLiteDatabase.execSQL("UPDATE COMPONENT_INFO SET STC_HUE ='360' WHERE STC_HUE =='100' ;");
        return true;
    }

    public boolean correctResIdsForBackground(SQLiteDatabase sQLiteDatabase) {
        Cursor rawQuery = sQLiteDatabase.rawQuery("SELECT TEMPLATE_ID, FRAME_NAME FROM TEMPLATES WHERE TYPE = 'USER' AND PROFILE_TYPE IN ('Abstract','Zig Zag','Creative Design','Dot','Wood','Water color','Blur','Nature','Black and white','Texture')", null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            return false;
        }
        do {
            int i = rawQuery.getInt(0);
            String string = rawQuery.getString(1);
            String replaceAll = string.replaceAll("[^0-9]", "");
            try {
                int parseInt = Integer.parseInt(replaceAll) + 1;
                if (parseInt > 0) {
                    String replaceAll2 = string.replaceAll(replaceAll, String.valueOf(parseInt)).replaceAll("\\s+", "");
                    StringBuilder stringBuilder = new StringBuilder();
                    stringBuilder.append("UPDATE TEMPLATES SET FRAME_NAME ='");
                    stringBuilder.append(replaceAll2);
                    stringBuilder.append("'  WHERE TEMPLATE_ID = ");
                    stringBuilder.append(i);
                    stringBuilder.append(" ;");
                    sQLiteDatabase.execSQL(stringBuilder.toString());
                }
            } catch (NumberFormatException unused) {
            }
        } while (rawQuery.moveToNext());
        return false;
    }

    public boolean correctResIdsForTexture(SQLiteDatabase sQLiteDatabase) {
        Cursor rawQuery = sQLiteDatabase.rawQuery("SELECT TEMPLATE_ID, FRAME_NAME FROM TEMPLATES WHERE TYPE = 'USER' AND PROFILE_TYPE IN ('Texture')", null);
        if (rawQuery == null || rawQuery.getCount() <= 0 || !rawQuery.moveToFirst()) {
            return false;
        }
        do {
            int i = rawQuery.getInt(0);
            String string = rawQuery.getString(1);
            String replaceAll = string.replaceAll("[^0-9]", "");
            try {
                int parseInt = Integer.parseInt(replaceAll) + 1;
                if (parseInt > 0) {
                    String replaceAll2 = string.replaceAll(replaceAll, String.valueOf(parseInt)).replaceAll("\\s+", "");
                    StringBuilder stringBuilder = new StringBuilder();
                    stringBuilder.append("UPDATE TEMPLATES SET FRAME_NAME ='");
                    stringBuilder.append(replaceAll2);
                    stringBuilder.append("'  WHERE TEMPLATE_ID = ");
                    stringBuilder.append(i);
                    stringBuilder.append(" ;");
                    sQLiteDatabase.execSQL(stringBuilder.toString());
                }
            } catch (NumberFormatException unused) {
            }
        } while (rawQuery.moveToNext());
        return false;
    }

    public boolean deleteTemplateInfo(int i) {
        try {
            SQLiteDatabase writableDatabase = getWritableDatabase();
            StringBuilder stringBuilder = new StringBuilder();
            stringBuilder.append("DELETE FROM TEMPLATES WHERE TEMPLATE_ID='");
            stringBuilder.append(i);
            stringBuilder.append("'");
            writableDatabase.execSQL(stringBuilder.toString());
            stringBuilder = new StringBuilder();
            stringBuilder.append("DELETE FROM COMPONENT_INFO WHERE TEMPLATE_ID='");
            stringBuilder.append(i);
            stringBuilder.append("'");
            writableDatabase.execSQL(stringBuilder.toString());
            stringBuilder = new StringBuilder();
            stringBuilder.append("DELETE FROM TEXT_INFO WHERE TEMPLATE_ID='");
            stringBuilder.append(i);
            stringBuilder.append("'");
            writableDatabase.execSQL(stringBuilder.toString());
            writableDatabase.close();
            return true;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }
}
