package com.AccountName.thumbnailmaker.scale;

import android.graphics.Bitmap;
import android.graphics.Rect;
import android.net.Uri;
import com.bumptech.glide.load.Key;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;

public final class ImageSource {
    static final String ASSET_SCHEME = "file:///android_asset/";
    static final String FILE_SCHEME = "file:///";
    private final Bitmap bitmap;
    private boolean cached;
    private final Integer resource;
    private int sHeight;
    private Rect sRegion;
    private int sWidth;
    private boolean tile;
    private final Uri uri;

    private ImageSource(Bitmap bitmap, boolean z) {
        this.bitmap = bitmap;
        this.uri = null;
        this.resource = null;
        this.tile = false;
        this.sWidth = bitmap.getWidth();
        this.sHeight = bitmap.getHeight();
        this.cached = z;
    }

    private ImageSource(Uri uri) {
        String uri2 = uri.toString();
        if (uri2.startsWith(FILE_SCHEME) && !new File(uri2.substring(FILE_SCHEME.length() - 1)).exists()) {
            try {
                uri = Uri.parse(URLDecoder.decode(uri2, Key.STRING_CHARSET_NAME));
            } catch (UnsupportedEncodingException unused) {
            }
        }
        this.bitmap = null;
        this.uri = uri;
        this.resource = null;
        this.tile = true;
    }

    private ImageSource(int i) {
        this.bitmap = null;
        this.uri = null;
        this.resource = Integer.valueOf(i);
        this.tile = true;
    }

    public static ImageSource resource(int i) {
        return new ImageSource(i);
    }

    public static ImageSource asset(String str) {
        if (str == null) {
            throw new NullPointerException("Asset name must not be null");
        }
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append(ASSET_SCHEME);
        stringBuilder.append(str);
        return uri(stringBuilder.toString());
    }

    public static ImageSource uri(String str) {
        if (str == null) {
            throw new NullPointerException("Uri must not be null");
        }
        if (!str.contains("://")) {
            if (str.startsWith("/")) {
                str = str.substring(1);
            }
            StringBuilder stringBuilder = new StringBuilder();
            stringBuilder.append(FILE_SCHEME);
            stringBuilder.append(str);
            str = stringBuilder.toString();
        }
        return new ImageSource(Uri.parse(str));
    }

    public static ImageSource uri(Uri uri) {
        if (uri != null) {
            return new ImageSource(uri);
        }
        throw new NullPointerException("Uri must not be null");
    }

    public static ImageSource bitmap(Bitmap bitmap) {
        if (bitmap != null) {
            return new ImageSource(bitmap, false);
        }
        throw new NullPointerException("Bitmap must not be null");
    }

    public static ImageSource cachedBitmap(Bitmap bitmap) {
        if (bitmap != null) {
            return new ImageSource(bitmap, true);
        }
        throw new NullPointerException("Bitmap must not be null");
    }

    public ImageSource tilingEnabled() {
        return tiling(true);
    }

    public ImageSource tilingDisabled() {
        return tiling(false);
    }

    public ImageSource tiling(boolean z) {
        this.tile = z;
        return this;
    }

    public ImageSource region(Rect rect) {
        this.sRegion = rect;
        setInvariants();
        return this;
    }

    public ImageSource dimensions(int i, int i2) {
        if (this.bitmap == null) {
            this.sWidth = i;
            this.sHeight = i2;
        }
        setInvariants();
        return this;
    }

    private void setInvariants() {
        if (this.sRegion != null) {
            this.tile = true;
            this.sWidth = this.sRegion.width();
            this.sHeight = this.sRegion.height();
        }
    }

    /* Access modifiers changed, original: protected|final */
    public final Uri getUri() {
        return this.uri;
    }

    /* Access modifiers changed, original: protected|final */
    public final Bitmap getBitmap() {
        return this.bitmap;
    }

    /* Access modifiers changed, original: protected|final */
    public final Integer getResource() {
        return this.resource;
    }

    /* Access modifiers changed, original: protected|final */
    public final boolean getTile() {
        return this.tile;
    }

    /* Access modifiers changed, original: protected|final */
    public final int getSWidth() {
        return this.sWidth;
    }

    /* Access modifiers changed, original: protected|final */
    public final int getSHeight() {
        return this.sHeight;
    }

    /* Access modifiers changed, original: protected|final */
    public final Rect getSRegion() {
        return this.sRegion;
    }

    /* Access modifiers changed, original: protected|final */
    public final boolean isCached() {
        return this.cached;
    }
}
