package com.AccountName.thumbnailmaker.scale;

import android.content.Context;
import android.content.pm.PackageManager;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.net.Uri;
import android.text.TextUtils;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;

public class SkiaImageDecoder implements ImageDecoder {
    private static final String ASSET_PREFIX = "file:///android_asset/";
    private static final String FILE_PREFIX = "file://";
    private static final String RESOURCE_PREFIX = "android.resource://";
    private final Config bitmapConfig;

    public SkiaImageDecoder() {
        this(null);
    }

    public SkiaImageDecoder(Config config) {
        Config preferredBitmapConfig = SubsamplingScaleImageView.getPreferredBitmapConfig();
        if (config != null) {
            this.bitmapConfig = config;
        } else if (preferredBitmapConfig != null) {
            this.bitmapConfig = preferredBitmapConfig;
        } else {
            this.bitmapConfig = Config.RGB_565;
        }
    }


    public Bitmap decode(Context context, Uri uri) {
        Bitmap decodeResource = null;
        Throwable th;
        String uri2 = uri.toString();
        Options options = new Options();
        options.inPreferredConfig = this.bitmapConfig;
        InputStream inputStream = null;
        if (uri2.startsWith(RESOURCE_PREFIX)) {
            Resources resources = null;
            uri2 = uri.getAuthority();
            if (context.getPackageName().equals(uri2)) {
                resources = context.getResources();
            } else {
                try {
                    resources = context.getPackageManager().getResourcesForApplication(uri2);
                } catch (PackageManager.NameNotFoundException e) {
                    e.printStackTrace();
                }
            }
            List pathSegments = uri.getPathSegments();
            int size = pathSegments.size();
            int i = 0;
            if (size == 2 && ((String) pathSegments.get(0)).equals("drawable")) {
                i = resources.getIdentifier((String) pathSegments.get(1), "drawable", uri2);
            } else if (size == 1 && TextUtils.isDigitsOnly((CharSequence) pathSegments.get(0))) {
                try {
                    i = Integer.parseInt((String) pathSegments.get(0));
                } catch (NumberFormatException unused) {
                }
            }
            decodeResource = BitmapFactory.decodeResource(context.getResources(), i, options);
        } else if (uri2.startsWith(ASSET_PREFIX)) {
            try {
                decodeResource = BitmapFactory.decodeStream(context.getAssets().open(uri2.substring(ASSET_PREFIX.length())), null, options);
            } catch (IOException e) {
                e.printStackTrace();
            }
        } else if (uri2.startsWith(FILE_PREFIX)) {
            try {
                decodeResource = BitmapFactory.decodeFile(uri2.substring(FILE_PREFIX.length()), options);
            } catch (OutOfMemoryError unused2) {
            }
        } else {
            try {
                InputStream openInputStream = context.getContentResolver().openInputStream(uri);
                try {
                    decodeResource = BitmapFactory.decodeStream(openInputStream, null, options);
                    if (openInputStream != null) {
                        openInputStream.close();
                    }
                } catch (Throwable th2) {
                    th = th2;
                    inputStream = openInputStream;
                    if (inputStream != null) {
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (Exception unused3) {
                    }
                }
                try {
                    throw th;
                } catch (Throwable throwable) {
                    throwable.printStackTrace();
                }
            }
        }
        if (decodeResource != null) {
            return decodeResource;
        }
        throw new RuntimeException("Skia image region decoder returned null bitmap - image format may not be supported");
    }
}
