package com.AccountName.thumbnailmaker.utility;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.Resources;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.Shader.TileMode;
import android.graphics.Typeface;
import android.net.Uri;
import android.os.Build.VERSION;
import android.os.ParcelFileDescriptor;
import android.provider.MediaStore.Images.Media;
import android.text.SpannableString;
import android.text.SpannableStringBuilder;
import android.view.Display;
import android.view.View;
import android.view.WindowManager;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;

import com.AccountName.thumbnailmaker.R;
import com.SimplyEntertaining.thumbnailmaker.main.JniUtils;

import java.io.FileDescriptor;
import java.io.IOException;

public class ImageUtils {
    public static float getnewHeight(int i, int i2, float f, float f2) {
        return (((float) i2) * f) / ((float) i);
    }

    public static float getnewWidth(int i, int i2, float f, float f2) {
        return (((float) i) * f2) / ((float) i2);
    }

    public static Bitmap getBitmapFromUri(Context context, Uri uri, float f, float f2) throws IOException {
        OutOfMemoryError e;
        Bitmap bitmap = null;
        try {
            ParcelFileDescriptor openFileDescriptor = context.getContentResolver().openFileDescriptor(uri, "r");
            FileDescriptor fileDescriptor = openFileDescriptor.getFileDescriptor();
            Options options = new Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeFileDescriptor(fileDescriptor, null, options);
            Options options2 = new Options();
            if (f <= f2) {
                f = f2;
            }
            int i = (int) f;
            options2.inSampleSize = getClosestResampleSize(options.outWidth, options.outHeight, i);
            Bitmap decodeFileDescriptor = BitmapFactory.decodeFileDescriptor(fileDescriptor, null, options2);
            try {
                Matrix matrix = new Matrix();
                if (decodeFileDescriptor.getWidth() > i || decodeFileDescriptor.getHeight() > i) {
                    Options resampling = getResampling(decodeFileDescriptor.getWidth(), decodeFileDescriptor.getHeight(), i);
                    matrix.postScale(((float) resampling.outWidth) / ((float) decodeFileDescriptor.getWidth()), ((float) resampling.outHeight) / ((float) decodeFileDescriptor.getHeight()));
                }
                String realPathFromURI = getRealPathFromURI(uri, context);
                if (new Integer(VERSION.SDK).intValue() > 4) {
                    int exifRotation = ExifUtils.getExifRotation(realPathFromURI);
                    if (exifRotation != 0) {
                        matrix.postRotate((float) exifRotation);
                    }
                }
                bitmap = Bitmap.createBitmap(decodeFileDescriptor, 0, 0, decodeFileDescriptor.getWidth(), decodeFileDescriptor.getHeight(), matrix, true);
                openFileDescriptor.close();
            } catch (OutOfMemoryError e2) {
                e = e2;
                bitmap = decodeFileDescriptor;
                e.printStackTrace();
                return bitmap;
            }
        } catch (OutOfMemoryError e3) {
            e = e3;
        }
        return bitmap;
    }

    public static Bitmap getResampleImageBitmap(Uri uri, Context context, int i) throws IOException {
        try {
            return resampleImage(getRealPathFromURI(uri, context), i);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public static Bitmap getResampleImageBitmap(Uri uri, Context context) throws IOException {
        String realPathFromURI = getRealPathFromURI(uri, context);
        try {
            Display defaultDisplay = ((WindowManager) context.getSystemService(Context.WINDOW_SERVICE)).getDefaultDisplay();
            Point point = new Point();
            defaultDisplay.getSize(point);
            int i = point.x;
            int i2 = point.y;
            return resampleImage(realPathFromURI, i);
        } catch (Exception e) {
            e.printStackTrace();
            return Media.getBitmap(context.getContentResolver(), Uri.parse(realPathFromURI));
        }
    }

    @SuppressLint({"UseValueOf"})
    public static Bitmap resampleImage(String str, int i) throws Exception {
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(str, options);
        Options options2 = new Options();
        options2.inSampleSize = getClosestResampleSize(options.outWidth, options.outHeight, i);
        Bitmap decodeFile = BitmapFactory.decodeFile(str, options2);
        Matrix matrix = new Matrix();
        if (decodeFile.getWidth() > i || decodeFile.getHeight() > i) {
            Options resampling = getResampling(decodeFile.getWidth(), decodeFile.getHeight(), i);
            matrix.postScale(((float) resampling.outWidth) / ((float) decodeFile.getWidth()), ((float) resampling.outHeight) / ((float) decodeFile.getHeight()));
        }
        if (new Integer(VERSION.SDK).intValue() > 4) {
            int exifRotation = ExifUtils.getExifRotation(str);
            if (exifRotation != 0) {
                matrix.postRotate((float) exifRotation);
            }
        }
        return Bitmap.createBitmap(decodeFile, 0, 0, decodeFile.getWidth(), decodeFile.getHeight(), matrix, true);
    }

    public static Options getResampling(int i, int i2, int i3) {
        Options options = new Options();
        float f = i > i2 ? ((float) i3) / ((float) i) : i2 > i ? ((float) i3) / ((float) i2) : ((float) i3) / ((float) i);
        options.outWidth = (int) ((((float) i) * f) + 0.5f);
        options.outHeight = (int) ((((float) i2) * f) + 0.5f);
        return options;
    }

    public static int getClosestResampleSize(int cx, int cy, int maxDim) {
        int max = Math.max(cx, cy);
        int resample = 1;
        while (resample < Integer.MAX_VALUE) {
            if (resample * maxDim > max) {
                resample--;
                break;
            }
            resample++;
        }
        return resample > 0 ? resample : 1;
    }

    public static Options getBitmapDims(String str) throws Exception {
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(str, options);
        return options;
    }

    public static String getRealPathFromURI(Uri uri, Context context) {
        try {
            String path;
            Cursor query = context.getContentResolver().query(uri, null, null, null, null);
            if (query == null) {
                path = uri.getPath();
            } else {
                query.moveToFirst();
                @SuppressLint("Range") String string = query.getString(query.getColumnIndex("_data"));
                query.close();
                path = string;
            }
            return path;
        } catch (Exception e) {
            e.printStackTrace();
            return uri.toString();
        }
    }


    public static Bitmap resizeBitmap(Bitmap bitmap, int i, int i2) {
        if (bitmap == null) {
            return null;
        }
        try {
            int[] resizeDimensJni = JniUtils.getResizeDimensJni(bitmap.getWidth(), bitmap.getHeight(), i, i2);
            return Bitmap.createScaledBitmap(bitmap, resizeDimensJni[0], resizeDimensJni[1], false);
        } catch (Error | Exception e) {
            e.printStackTrace();
            return bitmap;
        }
    }

    public static Bitmap resizeBitmap1(Bitmap bitmap, int i, int i2) {
        if (bitmap == null) {
            return null;
        }
        int[] resizeDimensJni = JniUtils.getResizeDimensJni(bitmap.getWidth(), bitmap.getHeight(), i, i2);
        return Bitmap.createScaledBitmap(bitmap, resizeDimensJni[0], resizeDimensJni[1], false);
    }

    public static int[] getOptimazedDimension(float f, float f2, float f3, float f4) {
        return JniUtils.getResizeDimensJni((int) f, (int) f2, (int) f3, (int) f4);
//        int[] ans = new int[2];
//
//        int wr = (int) f3;
//        int hr = (int) f4;
//        ans[0] = (int) f;
//        ans[1] = (int) f2;
//        int rat1 = ans[0] / ans[1];
//        int rat2 = ans[1] / ans[0];
//        if (ans[0] > wr) {
//            if (wr * rat2 > hr) {
//                ans[1] = hr;
//                ans[0] = ans[1] * rat1;
//            } else {
//                ans[0] = wr;
//                ans[1] = ans[0] * rat2;
//            }
//        } else if (ans[1] > hr) {
//            ans[1] = hr;
//            ans[0] = ans[1] * rat1;
//            if (ans[0] > wr) {
//                ans[0] = wr;
//                ans[1] = ans[0] * rat2;
//            }
//        } else if (rat1 > 0.75f) {
//            if (wr * rat2 > hr) {
//                ans[1] = hr;
//                ans[0] = ans[1] * rat1;
//            } else {
//                ans[0] = wr;
//                ans[1] = ans[0] * rat2;
//            }
//        } else if (rat2 > 1.5f) {
//            ans[1] = hr;
//            ans[0] = ans[1] * rat1;
//            if (ans[0] > wr) {
//                ans[0] = wr;
//                ans[1] = ans[0] * rat2;
//            }
//        } else if (wr * rat2 > hr) {
//            ans[1] = hr;
//            ans[0] = ans[1] * rat1;
//        } else {
//            ans[0] = wr;
//            ans[1] = ans[0] * rat2;
//        }
//
//        return ans;
    }

    public static Bitmap cropInRatio(Bitmap bitmap, int i, int i2) {
        float width = (float) bitmap.getWidth();
        float height = (float) bitmap.getHeight();
        float f = getnewHeight(i, i2, width, height);
        float f2 = getnewWidth(i, i2, width, height);
        Bitmap createBitmap = (f2 <= width && f2 < width) ? Bitmap.createBitmap(bitmap, (int) ((width - f2) / 2.0f), 0, (int) f2, (int) height) : null;
        if (f <= height && f < height) {
            createBitmap = Bitmap.createBitmap(bitmap, 0, (int) ((height - f) / 2.0f), (int) width, (int) f);
        }
        return (f2 == width && f == height) ? bitmap : createBitmap;
    }

    public static int dpToPx(Context context, int i) {
        float f = (float) i;
        try {
            context.getResources();
            return (int) (f * Resources.getSystem().getDisplayMetrics().density);
        } catch (Exception e) {
            e.printStackTrace();
            return i;
        }
    }

    public static Bitmap cropCenterBitmap(Bitmap bitmap, int i, int i2) {
        if (bitmap == null) {
            return null;
        }
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        if (width < i && height < i2) {
            return bitmap;
        }
        int i3 = 0;
        int i4 = width > i ? (width - i) / 2 : 0;
        if (height > i2) {
            i3 = (height - i2) / 2;
        }
        if (i > width) {
            i = width;
        }
        if (i2 > height) {
            i2 = height;
        }
        return Bitmap.createBitmap(bitmap, i4, i3, i, i2);
    }

    public static Bitmap getTiledBitmap(Context context, int i, int i2, int i3) {
        Rect rect = new Rect(0, 0, i2, i3);
        Paint paint = new Paint();
        Options options = new Options();
        options.inScaled = false;
        paint.setShader(new BitmapShader(BitmapFactory.decodeResource(context.getResources(), i, options), TileMode.REPEAT, TileMode.REPEAT));
        Bitmap createBitmap = Bitmap.createBitmap(i2, i3, Config.ARGB_8888);
        new Canvas(createBitmap).drawRect(rect, paint);
        return createBitmap;
    }

    public static Bitmap getTiledBitmap(Context context, String str, int i, int i2) {
        Rect rect = new Rect(0, 0, i, i2);
        Paint paint = new Paint();
        Options options = new Options();
        options.inScaled = false;
        byte[] decryptResourceJni = JniUtils.decryptResourceJni(context, str);
        paint.setShader(new BitmapShader(BitmapFactory.decodeByteArray(decryptResourceJni, 0, decryptResourceJni.length, options), TileMode.REPEAT, TileMode.REPEAT));
        Bitmap createBitmap = Bitmap.createBitmap(i, i2, Config.ARGB_8888);
        new Canvas(createBitmap).drawRect(rect, paint);
        return createBitmap;
    }

    public static CharSequence getSpannableString(Context context, Typeface typeface, int i) {
        SpannableString spannableString = new SpannableString(context.getResources().getString(i));
        spannableString.setSpan(new CustomTypefaceSpan(typeface), 0, context.getResources().getString(i).length(), 0);
        SpannableStringBuilder append = new SpannableStringBuilder().append(spannableString);
        return append.subSequence(0, append.length());
    }

    public static CharSequence getSpannableString(Context context, Typeface typeface, String str) {
        SpannableString spannableString = new SpannableString(str);
        spannableString.setSpan(new CustomTypefaceSpan(typeface), 0, str.length(), 0);
        SpannableStringBuilder append = new SpannableStringBuilder().append(spannableString);
        return append.subSequence(0, append.length());
    }

    public static void applyBounceAnimation(View view) {
        // Load the animation from the XML file
        Animation animation = AnimationUtils.loadAnimation(view.getContext(), R.anim.bounce);

        // Set a listener to remove the animation when it's done
        animation.setAnimationListener(new Animation.AnimationListener() {
            @Override
            public void onAnimationStart(Animation animation) {
            }

            @Override
            public void onAnimationEnd(Animation animation) {
                view.setAnimation(null);
            }

            @Override
            public void onAnimationRepeat(Animation animation) {
            }
        });

        // Apply the animation to the view
        view.startAnimation(animation);
    }
}
