package com.AccountName.thumbnailmaker.utility;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.BitmapShader;
import android.graphics.Camera;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.ColorFilter;
import android.graphics.LightingColorFilter;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathMeasure;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader.TileMode;
import android.graphics.Typeface;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.GradientDrawable.Orientation;
import android.os.AsyncTask;
import android.os.Environment;

import androidx.core.graphics.ColorUtils;
import androidx.core.view.ViewCompat;

import android.text.Layout.Alignment;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.util.Log;
import android.widget.Toast;

import com.AccountName.thumbnailmaker.R;
import com.SimplyEntertaining.thumbnailmaker.main.JniUtils;
import com.AccountName.thumbnailmaker.main.TemplateInfo;
import com.AccountName.thumbnailmaker.utility.GPUImageFilterTools.FilterAdjuster;
import com.msl.demo.view.ColorFilterGenerator;
import com.msl.demo.view.ComponentInfo;
import com.msl.textmodule.TextInfo;

import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;

import jp.co.cyberagent.android.gpuimage.GPUImage;

import jp.co.cyberagent.android.gpuimage.filter.GPUImageGaussianBlurFilter;

import org.json.JSONException;
import org.json.JSONObject;

public class ViewTemplateCanvasFinal {
    private Context context;
    private int curTileId = 0;
    AsyncTask job;
    boolean jobWork = false;
    Bitmap outputBitmap = null;
    Canvas outputCanvas;
    float screenH;
    float screenToImageRatio = 1.0f;
    float screenW;
    int targetDensity = 640;
    float viewHeight;
    float viewWidth;

    public boolean isValidWordWrap(char c, char c2) {
        return c == ' ' || c == '-';
    }

    public ViewTemplateCanvasFinal(Context context, float f, float f2, float f3, float f4, AsyncTask asyncTask, boolean z, int i) {
        this.context = context;
        this.job = asyncTask;
        this.jobWork = z;
        this.screenW = f;
        this.screenH = f2;
        this.viewWidth = f3;
        this.viewHeight = f4;
        this.targetDensity = i;
        this.screenToImageRatio = f / f3;
    }

    public Bitmap getTemplateBitmap(TemplateInfo templateInfo, HashMap<Integer, Object> hashMap) {
        if (this.jobWork && this.job.isCancelled()) {
            return null;
        }
        int i = 90;
        try {
            i = (int) (((float) Integer.parseInt(templateInfo.getSEEK_VALUE())) / this.screenToImageRatio);
        } catch (NumberFormatException e) {
            e.printStackTrace();
        }
        this.outputBitmap = Bitmap.createBitmap((int) this.viewWidth, (int) this.viewHeight, Config.ARGB_8888);
        this.outputCanvas = new Canvas(this.outputBitmap);
        this.outputCanvas.setDensity(this.targetDensity);
        if (this.jobWork && this.job.isCancelled()) {
            return null;
        }
        Bitmap resizeBitmap1;
        Paint paint;
        int parseColor;
        Options options;
        String profile_type = templateInfo.getPROFILE_TYPE();
        if (profile_type.equals("Abstract") || profile_type.equals("Zig Zag") || profile_type.equals("Creative Design") || profile_type.equals("Dot") || profile_type.equals("Wood") || profile_type.equals("Water color") || profile_type.equals("Blur") || profile_type.equals("Nature") || profile_type.equals("Black and white")) {
            try {
                Options options2 = new Options();
                options2.inTargetDensity = this.targetDensity;
                byte[] decryptResourceJni = JniUtils.decryptResourceJni(this.context, templateInfo.getFRAME_NAME());
                resizeBitmap1 = ImageUtils.resizeBitmap1(getCroppedBitmap(BitmapFactory.decodeByteArray(decryptResourceJni, 0, decryptResourceJni.length, options2), templateInfo), (int) this.viewWidth, (int) this.viewHeight);
                resizeBitmap1.setDensity(this.targetDensity);
                paint = new Paint(1);
                paint.setAntiAlias(true);
                paint.setFilterBitmap(true);
                this.outputCanvas.drawBitmap(resizeBitmap1, 0.0f, 0.0f, paint);
            } catch (Error | Exception e2) {
                e2.printStackTrace();
                return null;
            }
        } else if (templateInfo.getPROFILE_TYPE().equals("Texture")) {
            drawOnCanvas(templateInfo.getFRAME_NAME(), this.outputCanvas, i, templateInfo.getOVERLAY_BLUR());
        } else if (templateInfo.getPROFILE_TYPE().equals("Color")) {
            profile_type = templateInfo.getTEMPCOLOR();
            try {
                StringBuilder stringBuilder = new StringBuilder();
                stringBuilder.append("#");
                stringBuilder.append(profile_type);
                parseColor = Color.parseColor(stringBuilder.toString());
            } catch (NumberFormatException e3) {
                e3.printStackTrace();
                parseColor = -1;
            }
            Color.red(parseColor);
            Color.green(parseColor);
            Color.blue(parseColor);
            Color.alpha(parseColor);
            this.outputCanvas.drawColor(parseColor);
        } else if (templateInfo.getPROFILE_TYPE().equals("Gradient")) {
            try {
                JSONObject jSONObject = new JSONObject(templateInfo.getTEMPCOLOR());
                String string = jSONObject.getString("Orient");
                int i2 = jSONObject.getInt("Color1");
                int i3 = jSONObject.getInt("Color2");
                int[] optimazedDimension = ImageUtils.getOptimazedDimension(2.0f, 1.0f, this.screenW, this.screenH);
                GradientDrawable gradientDrawable = new GradientDrawable(Orientation.valueOf(string), new int[]{i2, i3});
                gradientDrawable.mutate();
                if (jSONObject.getString("Type").equals("LINEAR")) {
                    gradientDrawable.setGradientType(GradientDrawable.LINEAR_GRADIENT);
                } else {
                    gradientDrawable.setGradientType(GradientDrawable.RADIAL_GRADIENT);
                    if (optimazedDimension[0] > optimazedDimension[1]) {
                        gradientDrawable.setGradientRadius((float) ((optimazedDimension[1] * jSONObject.getInt("Prog_radius")) / 100));
                    } else {
                        gradientDrawable.setGradientRadius((float) ((optimazedDimension[0] * jSONObject.getInt("Prog_radius")) / 100));
                    }
                }
                resizeBitmap1 = Bitmap.createBitmap(optimazedDimension[0], optimazedDimension[1], Config.ARGB_8888);
                Canvas canvas = new Canvas(resizeBitmap1);
                gradientDrawable.setBounds(0, 0, optimazedDimension[0], optimazedDimension[1]);
                gradientDrawable.draw(canvas);
                this.outputCanvas.drawBitmap(getCroppedBitmap(resizeBitmap1, templateInfo), null, new Rect(0, 0, (int) this.viewWidth, (int) this.viewHeight), null);
            } catch (JSONException e4) {
                e4.printStackTrace();
            }
        } else if (templateInfo.getPROFILE_TYPE().equals("Temp_Path")) {
            File file = StorageConfiguration.getCategoryFileLocation();
            if (!file.exists() && !file.mkdirs()) {
                Log.d("", "Can't create directory to save image.");
                Toast.makeText(this.context, this.context.getResources().getString(R.string.create_dir_err), Toast.LENGTH_LONG).show();
            } else if (StorageConfiguration.getCategoryFileLocation().exists()) {
                File file2 = new File(templateInfo.getTEMP_PATH());
                if (file2.exists()) {
                    try {
                        options = new Options();
                        options.inTargetDensity = this.targetDensity;
                        resizeBitmap1 = BitmapFactory.decodeFile(file2.getAbsolutePath(), options);
                        resizeBitmap1.setDensity(this.targetDensity);
                        resizeBitmap1 = ImageUtils.resizeBitmap(resizeBitmap1, (int) this.viewWidth, (int) this.viewHeight);
                        paint = new Paint(1);
                        paint.setAntiAlias(true);
                        paint.setFilterBitmap(true);
                        this.outputCanvas.drawBitmap(resizeBitmap1, 0.0f, 0.0f, paint);
                    } catch (Error | Exception e5) {
                        e5.printStackTrace();
                    }
                }
            }
        }
        if (templateInfo.getOVERLAY_BLUR() > 0) {
            Paint paint2 = new Paint(1);
            paint2.setAlpha(templateInfo.getOVERLAY_BLUR());
            Bitmap gaussinBlur = gaussinBlur(this.context, this.outputBitmap);
            gaussinBlur.setDensity(this.targetDensity);
            this.outputCanvas.drawBitmap(gaussinBlur, 0.0f, 0.0f, paint2);
        }
        if (this.jobWork && this.job.isCancelled()) {
            return null;
        }
        if (!templateInfo.getOVERLAY_NAME().equals("")) {
            parseColor = this.context.getResources().getIdentifier(templateInfo.getOVERLAY_NAME(), "drawable", this.context.getPackageName());
            options = new Options();
            options.inTargetDensity = this.targetDensity;
            resizeBitmap1 = ImageUtils.resizeBitmap(ImageUtils.cropInRatio(BitmapFactory.decodeResource(this.context.getResources(), parseColor, options), (int) this.viewWidth, (int) this.viewHeight), (int) this.viewWidth, (int) this.viewHeight);
            paint = new Paint();
            paint.setAntiAlias(true);
            paint.setFilterBitmap(true);
            paint.setAlpha(templateInfo.getOVERLAY_OPACITY());
            this.outputCanvas.drawBitmap(resizeBitmap1, 0.0f, 0.0f, paint);
            resizeBitmap1.recycle();
        }
        if (this.jobWork && this.job.isCancelled()) {
            return null;
        }
        if (this.jobWork && this.job.isCancelled()) {
            return null;
        }
        try {
            addStickerAndTextToCanvas(this.outputCanvas, hashMap);
            return this.outputBitmap;
        } catch (Error | Exception e22) {
            e22.printStackTrace();
            return null;
        }
    }

    public Bitmap getWaterMarkedBitmap(Bitmap bitmap) {
        bitmap.setDensity(this.targetDensity);
        float width = (float) this.outputCanvas.getWidth();
        float height = (float) this.outputCanvas.getHeight();
        float width2 = (float) bitmap.getWidth();
        float height2 = (float) bitmap.getHeight();
        float f = width2 / height2;
        height2 /= width2;
        width2 = width / 4.0f;
        float f2 = width2 * height2;
        if (width2 > width) {
            bitmap = Bitmap.createScaledBitmap(bitmap, (int) width, (int) (height2 * width), false);
        } else if (f2 > height) {
            bitmap = Bitmap.createScaledBitmap(bitmap, (int) (f * height), (int) height, false);
        } else {
            bitmap = Bitmap.createScaledBitmap(bitmap, (int) width2, (int) f2, false);
            Log.i("testing", "In else condition");
        }
        this.outputCanvas.drawBitmap(bitmap, (float) ((this.outputBitmap.getWidth() - bitmap.getWidth()) - dpToPx(this.context, 2)), (float) ((this.outputBitmap.getHeight() - bitmap.getHeight()) - dpToPx(this.context, 2)), null);
        bitmap.recycle();
        return this.outputBitmap;
    }

    private boolean addStickerAndTextToCanvas(Canvas canvas, HashMap<Integer, Object> hashMap) {
        if (hashMap.size() != 0) {
            ArrayList arrayList = new ArrayList(hashMap.keySet());
            Collections.sort(arrayList);
            int size = arrayList.size();
            for (int i = 0; i < size; i++) {
                Object obj = hashMap.get(arrayList.get(i));
                if (obj instanceof ComponentInfo) {
                    int i2;
                    int i3;
                    ComponentInfo componentInfo = (ComponentInfo) obj;
                    float width = (float) componentInfo.getWIDTH();
                    float height = (float) componentInfo.getHEIGHT();
                    String field_two = componentInfo.getFIELD_TWO();
                    if ("".equals(field_two)) {
                        i2 = 0;
                        i3 = 0;
                    } else {
                        String[] split = field_two.split(",");
                        i3 = Integer.parseInt(split[0]);
                        i2 = Integer.parseInt(split[1]);
                    }
                    float f = this.screenW;
                    float f2 = this.screenH;
                    if (i3 < 0) {
                        f -= (float) i3;
                    }
                    if (i2 < 0) {
                        f2 -= (float) i2;
                    }
                    if (width > f) {
                        width = f;
                    }
                    if (height > f2) {
                        height = f2;
                    }
                    float pos_y = componentInfo.getPOS_Y() / this.screenToImageRatio;
                    width /= this.screenToImageRatio;
                    height /= this.screenToImageRatio;
                    componentInfo.setPOS_X(componentInfo.getPOS_X() / this.screenToImageRatio);
                    componentInfo.setPOS_Y(pos_y);
                    componentInfo.setWIDTH((int) width);
                    componentInfo.setHEIGHT((int) height);
                    if (!componentInfo.getFIELD_TWO().equals("")) {
                        componentInfo.setFIELD_TWO(getMargin(componentInfo.getFIELD_TWO()));
                    }
                    if (this.jobWork && this.job.isCancelled()) {
                        return false;
                    }
                    setStickerDrawable(canvas, componentInfo.getRES_ID(), componentInfo.getSTKR_PATH(), componentInfo);
                } else {
                    TextInfo textInfo = (TextInfo) obj;
                    if (!textInfo.getFIELD_TWO().equals("")) {
                        textInfo.setFIELD_TWO(getMargin(textInfo.getFIELD_TWO()));
                    }
                    if (this.jobWork && this.job.isCancelled()) {
                        return false;
                    }
                    setTextDrawableOnCanvas(canvas, textInfo);
                }
            }
        }
        return false;
    }

    private void setStickerDrawable(Canvas canvas, String str, String str2, ComponentInfo componentInfo) {
        Bitmap decodeByteArray = null;
        String str3 = str2;
        float pos_x = componentInfo.getPOS_X();
        float pos_y = componentInfo.getPOS_Y();
        float width = (float) componentInfo.getWIDTH();
        float height = (float) componentInfo.getHEIGHT();
        ColorFilter colorFilter = null;
        Options options;
        if (str3.equals("")) {
            options = new Options();
            options.inTargetDensity = this.targetDensity;
            byte[] decryptResourceJni = JniUtils.decryptResourceJni(this.context, str);
            decodeByteArray = BitmapFactory.decodeByteArray(decryptResourceJni, 0, decryptResourceJni.length, options);
        } else {
            File file = StorageConfiguration.getCategoryFileLocation();
            if (file.exists() || file.mkdirs()) {
                if (StorageConfiguration.getCategoryFileLocation().exists()) {
                    File file2 = new File(str3);
                    if (file2.exists()) {
                        try {
                            options = new Options();
                            options.inTargetDensity = this.targetDensity;
                            decodeByteArray = BitmapFactory.decodeFile(file2.getAbsolutePath(), options);
                        } catch (Error | Exception e) {
                            e.printStackTrace();
                        }
                    }
                }
                //decodeByteArray = null;
            } else {
                Log.d("", "Can't create directory to save image.");
                Toast.makeText(this.context, this.context.getResources().getString(R.string.create_dir_err), Toast.LENGTH_LONG).show();
                return;
            }
        }
        if (decodeByteArray != null) {
            float width2 = ((float) decodeByteArray.getWidth()) / ((float) decodeByteArray.getHeight());
            float dpToPx = ((float) dpToPx(this.context, 25)) / this.screenToImageRatio;
            pos_x += dpToPx;
            pos_y += dpToPx;
            dpToPx *= 2.0f;
            width -= dpToPx;
            height -= dpToPx;
            dpToPx = (((float) componentInfo.getScaleProg()) * width) / 10.0f;
            float scaleProg = (((float) componentInfo.getScaleProg()) * height) / 10.0f;
            pos_x += (width - dpToPx) / 2.0f;
            pos_y += (height - scaleProg) / 2.0f;
            width = dpToPx / width2;
            height = scaleProg * width2;
            if (dpToPx <= dpToPx && width <= scaleProg) {
                pos_y += (scaleProg - width) / 2.0f;
                scaleProg = width;
            } else if (height <= dpToPx && scaleProg <= scaleProg) {
                pos_x += (dpToPx - height) / 2.0f;
                dpToPx = height;
            }
            if (dpToPx <= 0.0f || scaleProg <= 0.0f) {
                StringBuilder stringBuilder = new StringBuilder();
                stringBuilder.append(dpToPx);
                stringBuilder.append(" ");
                stringBuilder.append(scaleProg);
                Log.e("Less then 0", stringBuilder.toString());
                return;
            }
            int i = (int) dpToPx;
            int i2 = (int) scaleProg;
            decodeByteArray = Bitmap.createScaledBitmap(decodeByteArray, i, i2, true);
            Camera camera = new Camera();
            i /= 2;
            i2 /= 2;
            camera.save();
            float yRotateProg = (float) componentInfo.getYRotateProg();
            scaleProg = (float) componentInfo.getZRotateProg();
            camera.rotateX(45.0f - ((float) componentInfo.getXRotateProg()));
            camera.rotateY(45.0f - yRotateProg);
            camera.rotateZ(scaleProg + 180.0f);
            camera.setLocation(0.0f, 0.0f, -8.0f / this.screenToImageRatio);
            Matrix matrix = new Matrix();
            camera.getMatrix(matrix);
            matrix.preTranslate((float) (-i), (float) (-i2));
            matrix.postRotate(componentInfo.getROTATION());
            camera.restore();
            Paint paint = new Paint();
            paint.setAlpha(Math.round((((float) componentInfo.getSTC_OPACITY()) / 100.0f) * 255.0f));
            if (componentInfo.getCOLORTYPE().equals("white")) {
                if (componentInfo.getSTC_COLOR() != 0) {
                    colorFilter = new LightingColorFilter(0, componentInfo.getSTC_COLOR());
                }
            } else if (componentInfo.getSTC_HUE() == 0) {
                colorFilter = new LightingColorFilter(0, -1);
            } else if (componentInfo.getSTC_HUE() == 360) {
                colorFilter = new LightingColorFilter(0, ViewCompat.MEASURED_STATE_MASK);
            } else if (componentInfo.getSTC_HUE() < 1 || componentInfo.getSTC_HUE() > 5) {
                colorFilter = ColorFilterGenerator.adjustHue((float) componentInfo.getSTC_HUE());
            }
            paint.setColorFilter(colorFilter);
            paint.setAntiAlias(true);
            paint.setFilterBitmap(true);
            if (componentInfo.getY_ROTATION() != 0.0f) {
                matrix.preScale(-1.0f, 1.0f, (float) i, (float) i2);
            }
            matrix.postTranslate(pos_x + ((float) i), pos_y + ((float) i2));
            canvas.drawBitmap(decodeByteArray, matrix, paint);
            decodeByteArray.recycle();
        }
    }

    private void setTextDrawableOnCanvas(Canvas canvas, TextInfo textInfo) {
        Bitmap bitmap;
        Bitmap createBitmap;
        int i;
        int width;
        float pos_x = textInfo.getPOS_X() / this.screenToImageRatio;
        float pos_y = textInfo.getPOS_Y() / this.screenToImageRatio;
        float width2 = ((float) textInfo.getWIDTH()) / this.screenToImageRatio;
        float height = ((float) textInfo.getHEIGHT()) / this.screenToImageRatio;
        int i2 = (int) 5.0f;
        float dpToPx = ((float) dpToPx(this.context, i2)) / this.screenToImageRatio;
        float dpToPx2 = ((float) dpToPx(this.context, i2)) / this.screenToImageRatio;
        float dpToPx3 = ((float) dpToPx(this.context, i2)) / this.screenToImageRatio;
        float dpToPx4 = ((float) dpToPx(this.context, i2)) / this.screenToImageRatio;
        dpToPx = width2 - (dpToPx * 2.0f);
        dpToPx2 = height - (dpToPx2 * 2.0f);
        if (dpToPx <= 0.0f) {
            dpToPx = 1.0f;
        }
        if (dpToPx2 <= 0.0f) {
            dpToPx2 = 1.0f;
        }
        Bitmap textBitmap2 = getTextBitmap2(textInfo, new Rect(0, 0, (int) dpToPx, (int) dpToPx2));
        dpToPx2 = width2 - (dpToPx3 * 2.0f);
        dpToPx4 = height - (dpToPx4 * 2.0f);
        if (dpToPx2 <= 0.0f || dpToPx4 <= 0.0f) {
            dpToPx = 0.0f;
            bitmap = null;
        } else {
            createBitmap = Bitmap.createBitmap((int) dpToPx2, (int) dpToPx4, Config.ARGB_8888);
            Canvas canvas2 = new Canvas(createBitmap);
            canvas2.setDensity(this.targetDensity);
            dpToPx2 = (dpToPx2 - ((float) textBitmap2.getWidth())) / 2.0f;
            dpToPx4 = (dpToPx4 - ((float) textBitmap2.getHeight())) / 2.0f;
            Paint paint = new Paint();
            paint.setAntiAlias(true);
            paint.setFilterBitmap(true);
            canvas2.drawBitmap(textBitmap2, dpToPx2, dpToPx4, paint);
            textBitmap2 = Bitmap.createBitmap(createBitmap.getWidth(), createBitmap.getHeight(), Config.ARGB_8888);
            Canvas canvas3 = new Canvas(textBitmap2);
            canvas3.setDensity(this.targetDensity);
            if (textInfo.getCurveRotateProg() == 200) {
                i = 0;
            } else {
                i = textInfo.getCurveRotateProg();
            }
            float[] curvingArray = getCurvingArray(createBitmap.getWidth(), createBitmap.getHeight(), (int) (((float) i) / this.screenToImageRatio));
            canvas3.translate(0.0f, 0.0f);
            canvas3.drawBitmapMesh(createBitmap, 8, 8, curvingArray, 0, null, 0, paint);
            createBitmap.recycle();
            Bitmap createBitmap2 = Bitmap.createBitmap(createBitmap.getWidth(), createBitmap.getHeight(), Config.ARGB_8888);
            Canvas canvas4 = new Canvas(createBitmap2);
            canvas4.setDensity(this.targetDensity);
            Camera camera = new Camera();
            width = textBitmap2.getWidth() / 2;
            int height2 = textBitmap2.getHeight() / 2;
            camera.save();
            float yRotateProg = (float) textInfo.getYRotateProg();
            float zRotateProg = (float) textInfo.getZRotateProg();
            camera.rotateX(45.0f - ((float) textInfo.getXRotateProg()));
            camera.rotateY(45.0f - yRotateProg);
            camera.rotateZ(zRotateProg + 180.0f);
            camera.setLocation(0.0f, 0.0f, -8.0f / this.screenToImageRatio);
            Matrix matrix = new Matrix();
            camera.getMatrix(matrix);
            matrix.preTranslate((float) (-width), (float) (-height2));
            camera.restore();
            matrix.postTranslate((float) width, (float) height2);
            canvas4.drawBitmap(textBitmap2, matrix, paint);
            textBitmap2.recycle();
            System.gc();
            Runtime.getRuntime().gc();
            bitmap = createBitmap2;
            dpToPx = 0.0f;
        }
        if (width2 > dpToPx && height > dpToPx) {
            Bitmap bitmap2;
            Canvas canvas5;
            int i3 = (int) width2;
            int i4 = (int) height;
            Bitmap createBitmap3 = Bitmap.createBitmap(i3, i4, Config.ARGB_8888);
            Canvas canvas6 = new Canvas(createBitmap3);
            canvas6.setDensity(this.targetDensity);
            Paint paint2 = new Paint();
            if (textInfo.getBG_COLOR() != 0) {
                paint2.setColor(textInfo.getBG_COLOR());
            } else {
                paint2.setColor(0);
            }
            canvas6.translate(0.0f, 0.0f);
            paint2.setAlpha(textInfo.getBG_ALPHA());
            paint2.setAntiAlias(true);
            paint2.setFilterBitmap(true);
            paint2.setSubpixelText(true);
            if (textInfo.getBG_DRAWABLE().equals("0")) {
                bitmap2 = createBitmap3;
                canvas5 = canvas6;
                canvas5.drawPaint(paint2);
            } else {
                Context context = this.context;
                Paint paint3 = paint2;
                i = this.context.getResources().getIdentifier(textInfo.getBG_DRAWABLE(), "drawable", this.context.getPackageName());
                int width3 = (int) (((float) textInfo.getWIDTH()) / this.screenToImageRatio);
                width = (int) (((float) textInfo.getHEIGHT()) / this.screenToImageRatio);
                bitmap2 = createBitmap3;
                canvas5 = canvas6;
                canvas5.drawBitmap(getTiledBitmap(context, i, width3, width, 0.5f), 0.0f, 0.0f, paint3);
            }
            if (bitmap != null) {
                canvas5.drawBitmap(bitmap, (width2 - ((float) bitmap.getWidth())) / 2.0f, (height - ((float) bitmap.getHeight())) / 2.0f, null);
            }
            Matrix matrix2 = new Matrix();
            i3 /= 2;
            i4 /= 2;
            matrix2.preTranslate((float) (-i3), (float) (-i4));
            matrix2.postRotate(textInfo.getROTATION());
            matrix2.postTranslate(pos_x + ((float) i3), pos_y + ((float) i4));
            Paint paint4 = new Paint();
            paint4.setAntiAlias(true);
            paint4.setFilterBitmap(true);
            paint4.setSubpixelText(true);
            createBitmap = bitmap2;
            canvas.drawBitmap(createBitmap, matrix2, paint4);
            if (bitmap != null) {
                bitmap.recycle();
            }
            createBitmap.recycle();
        }
    }

    private float[] getCurvingArray(int i, int i2, int i3) {
        int i4 = i / 8;
        i4 = i2 / 8;
        int i5 = 0;
        int i6 = i4 + 0;
        int i7 = (i4 * 2) + 0;
        int i8 = (i4 * 3) + 0;
        int i9 = (i4 * 4) + 0;
        int i10 = (i4 * 5) + 0;
        int i11 = (i4 * 6) + 0;
        i4 = (i4 * 7) + 0;
        int i12 = i2 + 0;
        int i13 = i + 0;
        int i14 = i3;
        Path mPath = mPath(0, 0, i13, 0, i14);
        Path mPath2 = mPath(0, i6, i13, i6, i14);
        Path mPath3 = mPath(0, i7, i13, i7, i14);
        Path mPath4 = mPath(0, i8, i13, i8, i14);
        Path mPath5 = mPath(0, i9, i13, i9, i14);
        Path mPath6 = mPath(0, i10, i13, i10, i14);
        Path mPath7 = mPath(0, i11, i13, i11, i14);
        Path mPath8 = mPath(0, i4, i13, i4, i14);
        Path mPath9 = mPath(0, i12, i13, i12, i14);
        Path[] pathArr = new Path[]{mPath, mPath2, mPath3, mPath4, mPath5, mPath6, mPath7, mPath8, mPath9};
        ArrayList arrayList = new ArrayList();
        for (Path pathMeasure : pathArr) {
            PathMeasure pathMeasure2 = new PathMeasure(pathMeasure, false);
            float[] fArr = new float[]{0.0f, 0.0f};
            for (float f = 0.0f; f <= 1.0f; f += 0.125f) {
                pathMeasure2.getPosTan(pathMeasure2.getLength() * f, fArr, null);
                arrayList.add(Float.valueOf(fArr[0]));
                arrayList.add(Float.valueOf(fArr[1]));
            }
        }
        float[] fArr2 = new float[arrayList.size()];
        while (i5 < fArr2.length) {
            fArr2[i5] = ((Float) arrayList.get(i5)).floatValue();
            i5++;
        }
        return fArr2;
    }

    public Path mPath(int i, int i2, int i3, int i4, int i5) {
        int i6 = i;
        int i7 = i2;
        int i8 = i3;
        int i9 = i4;
        Path path = new Path();
        int i10 = ((i8 - i6) / 2) + i6;
        int i11 = ((i9 - i7) / 2) + i7;
        double toRadians = Math.toRadians((Math.atan2((double) ((float) (i11 - i7)), (double) ((float) (i10 - i6))) * 57.29577951308232d) - 90.0d);
        double d = (double) i5;
        float cos = (float) (((double) i10) + (Math.cos(toRadians) * d));
        float sin = (float) (((double) i11) + (d * Math.sin(toRadians)));
        float f = (float) i6;
        float f2 = (float) i7;
        path.moveTo(f, f2);
        path.cubicTo(f, f2, cos, sin, (float) i8, (float) i9);
        return path;
    }


    private Bitmap getTextBitmap2(TextInfo textInfo, Rect rect) {
        float optimumTextSize;
        int i = 0;
        Bitmap createBitmap;
        Canvas canvas;
        String text = textInfo.getTEXT();
        StaticLayout staticLayout = null;
        ;
        TextPaint textPaint = new TextPaint(1);
        textPaint.density = this.context.getResources().getDisplayMetrics().density;
        try {
            Typeface createFromAsset;
            if (!textInfo.getFONT_NAME().equals("default")) {
                if (!textInfo.getFONT_NAME().equals("")) {
                    createFromAsset = Typeface.createFromAsset(this.context.getAssets(), textInfo.getFONT_NAME());
                    textPaint.setTypeface(createFromAsset);

                }
            } else {
                createFromAsset = Typeface.DEFAULT;
                textPaint.setTypeface(createFromAsset);
            }

            optimumTextSize = (float) getOptimumTextSize(10, 1000, text, new RectF((float) rect.left, (float) rect.top, (float) rect.width(), (float) rect.height()), textPaint);
            if (optimumTextSize >= 80.0f / this.screenToImageRatio) {
                i = (int) (optimumTextSize - (10.0f / this.screenToImageRatio));
            } else if (optimumTextSize > 80.0f / this.screenToImageRatio && optimumTextSize < 120.0f / this.screenToImageRatio) {
                i = (int) (optimumTextSize - (30.0f / this.screenToImageRatio));
            } else if (optimumTextSize <= 120.0f / this.screenToImageRatio || optimumTextSize >= 150.0f / this.screenToImageRatio) {
                i = (int) (optimumTextSize - (60.0f / this.screenToImageRatio));
            } else {
                i = (int) (optimumTextSize - (40.0f / this.screenToImageRatio));
            }
            textPaint.setTextSize((float) i);
            textPaint.setColor(textInfo.getTEXT_COLOR());
            textPaint.setAntiAlias(true);
            textPaint.setFilterBitmap(true);
            i = Math.round((((float) textInfo.getTEXT_ALPHA()) / 100.0f) * 255.0f);
            textPaint.setAlpha(i);
            textPaint.setShadowLayer(((float) textInfo.getSHADOW_PROG()) / this.screenToImageRatio, 0.0f, 0.0f, ColorUtils.setAlphaComponent(textInfo.getSHADOW_COLOR(), i));

            if (textInfo.getFIELD_THREE() != null) {
                staticLayout = new StaticLayout(text, textPaint, rect.width(), Alignment.ALIGN_CENTER, 1.0f, 0.0f, true);
            } else if (textInfo.getFIELD_THREE().equals("L")) {
                staticLayout = new StaticLayout(text, textPaint, rect.width(), Alignment.ALIGN_NORMAL, 1.0f, 0.0f, true);
            } else if (textInfo.getFIELD_THREE().equals("R")) {
                staticLayout = new StaticLayout(text, textPaint, rect.width(), Alignment.ALIGN_OPPOSITE, 1.0f, 0.0f, true);
            } else {
                staticLayout = new StaticLayout(text, textPaint, rect.width(), Alignment.ALIGN_CENTER, 1.0f, 0.0f, true);
            }
            createBitmap = Bitmap.createBitmap(rect.width(), rect.height(), Config.ARGB_8888);
            canvas = new Canvas(createBitmap);
            canvas.setDensity(this.targetDensity);
            canvas.save();
            getTextHeight(text, textPaint);
            staticLayout.getLineCount();
            canvas.translate((float) rect.left, (float) ((rect.height() - staticLayout.getHeight()) / 2));
            staticLayout.draw(canvas);
            canvas.restore();
            return createBitmap;
        } catch (Exception e) {
            e.printStackTrace();
        }
        optimumTextSize = (float) getOptimumTextSize(10, 1000, text, new RectF((float) rect.left, (float) rect.top, (float) rect.width(), (float) rect.height()), textPaint);
        if (optimumTextSize >= 80.0f / this.screenToImageRatio) {
        }
        textPaint.setTextSize((float) i);
        textPaint.setColor(textInfo.getTEXT_COLOR());
        textPaint.setAntiAlias(true);
        textPaint.setFilterBitmap(true);
        i = Math.round((((float) textInfo.getTEXT_ALPHA()) / 100.0f) * 255.0f);
        textPaint.setAlpha(i);
        textPaint.setShadowLayer(((float) textInfo.getSHADOW_PROG()) / this.screenToImageRatio, 0.0f, 0.0f, ColorUtils.setAlphaComponent(textInfo.getSHADOW_COLOR(), i));
        if (textInfo.getFIELD_THREE() != null) {
        }
        createBitmap = Bitmap.createBitmap(rect.width(), rect.height(), Config.ARGB_8888);
        canvas = new Canvas(createBitmap);
        canvas.setDensity(this.targetDensity);
        canvas.save();
        getTextHeight(text, textPaint);
        staticLayout.getLineCount();
        canvas.translate((float) rect.left, (float) ((rect.height() - staticLayout.getHeight()) / 2));
        staticLayout.draw(canvas);
        canvas.restore();
        return createBitmap;
    }

    private int getOptimumTextSize(int i, int i2, String str, RectF rectF, TextPaint textPaint) {
        return binarySearch(i, i2, str, rectF, textPaint);
    }

    private int binarySearch(int i, int i2, String str, RectF rectF, TextPaint textPaint) {
        i2--;
        int i3 = i;
        while (i <= i2) {
            i3 = (i + i2) >>> 1;
            int onTestSize = onTestSize(i3, str, rectF, textPaint);
            if (onTestSize < 0) {
                int i4 = i3 + 1;
                i3 = i;
                i = i4;
            } else if (onTestSize <= 0) {
                return i3;
            } else {
                i3--;
                i2 = i3;
            }
        }
        return i3;
    }

    public int onTestSize(int i, String str, RectF rectF, TextPaint textPaint) {
        textPaint.setTextSize((float) i);
        RectF rectF2 = new RectF();
        int i2 = 0;
        StaticLayout staticLayout = new StaticLayout(str, textPaint, (int) rectF.width(), Alignment.ALIGN_NORMAL, (float) 1, (float) 0, true);
        rectF2.bottom = (float) staticLayout.getHeight();
        int lineCount = staticLayout.getLineCount();
        int i3 = -1;
        while (i2 < lineCount) {
            int lineEnd = staticLayout.getLineEnd(i2);
            if (i2 < lineCount - 1 && lineEnd > 0 && !isValidWordWrap(str.charAt(lineEnd - 1), str.charAt(lineEnd))) {
                return 1;
            }
            if (((float) i3) < staticLayout.getLineRight(i2) - staticLayout.getLineLeft(i2)) {
                i3 = ((int) staticLayout.getLineRight(i2)) - ((int) staticLayout.getLineLeft(i2));
            }
            i2++;
        }
        rectF2.right = (float) i3;
        rectF2.offsetTo(0.0f, 0.0f);
        if (rectF.contains(rectF2)) {
            return -1;
        }
        return 1;
    }

    private float getTextHeight(String str, Paint paint) {
        Rect rect = new Rect();
        paint.setAntiAlias(true);
        paint.setFilterBitmap(true);
        paint.getTextBounds(str, 0, str.length(), rect);
        return (float) rect.height();
    }

    private boolean drawOnCanvas(String str, Canvas canvas, int i, int i2) {
        Rect rect = new Rect(0, 0, canvas.getWidth(), canvas.getHeight());
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        paint.setFilterBitmap(true);
        i = (int) (((float) i) + (10.0f / this.screenToImageRatio));
        Options options = new Options();
        options.inTargetDensity = this.targetDensity;
        byte[] decryptResourceJni = JniUtils.decryptResourceJni(this.context, str);
        Bitmap createScaledBitmap = Bitmap.createScaledBitmap(BitmapFactory.decodeByteArray(decryptResourceJni, 0, decryptResourceJni.length, options), i, i, true);
        createScaledBitmap.setDensity(this.targetDensity);
        paint.setShader(new BitmapShader(createScaledBitmap, TileMode.REPEAT, TileMode.REPEAT));
        canvas.drawRect(rect, paint);
        createScaledBitmap.recycle();
        return true;
    }

    public String getMargin(String str) {
        String[] split = str.split(",");
        int parseInt = Integer.parseInt(split[0]);
        parseInt = (int) (((float) parseInt) / this.screenToImageRatio);
        int parseInt2 = (int) (((float) Integer.parseInt(split[1])) / this.screenToImageRatio);
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append(String.valueOf(parseInt));
        stringBuilder.append(",");
        stringBuilder.append(String.valueOf(parseInt2));
        return stringBuilder.toString();
    }

    private Bitmap getTiledBitmap(Context context, int i, int i2, int i3, float f) {
        int i4 = (f > 0.0f ? 1 : (f == 0.0f ? 0 : -1));
        Rect rect = new Rect(0, 0, i2, i3);
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        paint.setFilterBitmap(true);
        paint.setShader(new BitmapShader(BitmapFactory.decodeResource(context.getResources(), i, new Options()), TileMode.REPEAT, TileMode.REPEAT));
        Bitmap createBitmap = Bitmap.createBitmap(i2, i3, Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        canvas.setDensity(this.targetDensity);
        canvas.drawRect(rect, paint);
        return createBitmap;
    }


    public int dpToPx(Context context, int i) {
        float f = (float) i;
        context.getResources();
        return (int) (f * Resources.getSystem().getDisplayMetrics().density);
    }

    private Bitmap gaussinBlur(Context context, Bitmap bitmap) {
        try {
            GPUImage gPUImage = new GPUImage(context);
            GPUImageGaussianBlurFilter gPUImageGaussianBlurFilter = new GPUImageGaussianBlurFilter();
            gPUImage.setFilter(gPUImageGaussianBlurFilter);
            new FilterAdjuster(gPUImageGaussianBlurFilter).adjust(100);
            gPUImage.requestRender();
            return gPUImage.getBitmapWithFilterApplied(bitmap);
        } catch (OutOfMemoryError e) {
            e.printStackTrace();
            throw e;
        }
    }

    private Bitmap getCroppedBitmap(Bitmap bitmap, TemplateInfo templateInfo) {
        return Bitmap.createBitmap(bitmap, (int) ((((float) bitmap.getWidth()) / templateInfo.getCiv_width()) * templateInfo.getCustom_X()), (int) ((((float) bitmap.getHeight()) / templateInfo.getCiv_height()) * templateInfo.getCustom_Y()), (int) ((((float) bitmap.getWidth()) / templateInfo.getCiv_width()) * templateInfo.getCustom_Wi()), (int) ((((float) bitmap.getHeight()) / templateInfo.getCiv_height()) * templateInfo.getCustom_He()));
    }
}
